@@ -4,9 +4,8 @@
 
 """ attempt to make a global usercache. not used yet. """
 
-# INIT SECTION
+__status__ = "ok"
+
+## global userhost cache
 
-# global userhost cache
 userhosts = {}
-
-# END SECTION
\ No newline at end of file
