@@ -2,29 +2,27 @@
 #
 #
 
-""" 
-    gozerbot config module. 
+""" gozerbot config module. """
 
-    :var config: default config object
+__status__ = "seen"
 
-"""
+## gozerbot imports
 
-__copyright__ = 'this file is in the public domain'
-
-# IMPORT SECTION
-
-# gozerbot imports
 from utils.exception import handle_exception
 from utils.log import rlog
 
-# simplejson imports
+## simplejson imports
 
 from simplejson import loads, dumps
 
-# basic imports
-import os, types, thread, logging
+## basic imports
 
-# END IMPORT
+import os
+import types
+import thread
+import logging
+
+## Config class
 
 class Config(dict):
 
@@ -32,13 +30,6 @@ class Config(dict):
         config class is a dict containing json strings. is writable to file 
         and human editable.
 
-        :param ddir: datadir where the config file lives
-        :type ddir: string
-        :param filename: filename of the config file
-        :type filename: string
-        :param inittxt: initial txt to fill the config file with
-        :type inittxt: string
-      
     """
 
     def __init__(self, ddir=None, filename=None, inittxt=None, verbose=False, *args, **kw):
@@ -47,51 +38,31 @@ class Config(dict):
         self.dir = ddir or 'gozerdata'
         self.filename = filename or 'config'
         self.cfile = self.dir + os.sep + self.filename
-
-        if hasattr(os, 'mkdir'):
-            #  check if provided dir exists if not create it
-            if not os.path.exists(self.dir):
-                os.mkdir(self.dir)
-
-            # see if initial data has to be written
-            if inittxt and not os.path.exists(self.cfile):
-                self.write_init(inittxt)
-
+        if not os.path.exists(self.dir): os.mkdir(self.dir)
+        if inittxt and not os.path.exists(self.cfile): self.write_init(inittxt)
         self.configlist = []
         self.lock = thread.allocate_lock()
         self.load(verbose)
 
     def __getitem__(self, item):
-        if not self.has_key(item):
-            return None
-        else:
-            return dict.__getitem__(self, item)
+        if self.has_key(item): return dict.__getitem__(self, item)
 
     def set(self, item, value):
+        """ set a config item. save the config file as well. """
         dict.__setitem__(self, item, value)
         self.save()
 
     def load(self, verbose=False):
-
-        """
-            load the config file.
-
-            .. literalinclude:: ../../gozerbot/config.py
-                :pyobject: Config.load
-
-        """
-
+        """ load the config file. """
         self.reload()
-
         if self.filename == 'mainconfig':
             self.setdefault('owner', [])
             self.setdefault('loglevel', 10)
             self.setdefault('loglist',  [])
             self.setdefault('resource', 'gozerbot')
-            self.setdefault('quitmsg', "http://gozerbot.googlecode.com")
+            self.setdefault('quitmsg', "http://pikacode.com/bthate/gozerbot")
             self.setdefault('mask', "700")
             self.setdefault('debug', 0)
-            self.setdefault('nodb', 0)
             self.setdefault('plugdeny', [])
             self.setdefault('db_driver', 'olddb')
             self.setdefault('dbtype', "sqlite")
@@ -102,8 +73,7 @@ class Config(dict):
             self.setdefault('loadlist', ["alias", "all", "at", "chanperm", "choice", "code", "core", "count", "fleet", "googletalk", "grep", "ignore", "irc", "jabber", "job", "misc", "nickcapture", "nickserv", "not", "quote", "reload", "rest", "reverse", "size", "sort", "tail", "tell", "to", "underauth", "uniq", "user", "userstate", "stats", "throttle"])
             self.setdefault('dotchars',  " .. ")
             self.setdefault('floodallow', 1)
-            self.setdefault('auto_register', 0)
-
+            self.setdefault('auto_register', 1)
         elif 'fleet' in self.dir:
             self.setdefault("enable", 1)
             self.setdefault("type", "irc")
@@ -119,93 +89,48 @@ class Config(dict):
             self.setdefault("username", "gozerbot")
             self.setdefault("realname", "GOZERBOT")
             self.setdefault("defaultcc", "!")
-            self.setdefault("quitmsg", "http://gozerbot.googlecode.com")
+            self.setdefault("quitmsg", "http://pikacode.com/bthate/gozerbot")
             self.setdefault("bindhost", "")
             self.setdefault("nolimiter", 0)
             self.setdefault("nickservpass", "")
             self.setdefault("nickservtxt", ["set unfiltered on", ])
-            self.setdefault("auto_register", 0)
+            self.setdefault("auto_register", 1)
             self.setdefault("stripident", 0)   
             self.setdefault("loadlist", [])    
-
         import gozerbot
         self['version'] = "GOZERBOT %s " % gozerbot.__version__
-        self['version'] += "RELEASE"
-
-        if verbose:
-            rlog(10, 'config', str(self))
+        self['version'] += "FINAL"
+        if verbose: rlog(10, 'config', str(self))
 
     def save(self):
-
-        """
-            save the config file.
-
-            :rtype: integer .. number of lines saved
-
-            .. literalinclude:: ../../gozerbot/config.py
-                :pyobject: Config.save
-
-
-        """
-
+        """ save the config file. """
         written = []
         curitem = None
-
         try:
-
             self.lock.acquire()
-
-            # read existing config file if available
-            try:
-                self.configlist = open(self.cfile, 'r').readlines()
-            except IOError:
-                self.configlist = []
-
-            # make temp file
+            try: self.configlist = open(self.cfile, 'r').readlines()
+            except IOError: self.configlist = []
             configtmp = open(self.cfile + '.tmp', 'w')
             teller = 0
-
-            # write header if not already there
-            if not self.configlist:
-                configtmp.write('# %s\n\n' % self.cfile)
-
-            # loop over original lines replacing updated data
+            if not self.configlist: configtmp.write('# %s\n\n' % self.cfile)
             for line in self.configlist:
                 teller += 1
-
-                # skip comment
-                if line.startswith('#'):
-                    configtmp.write(line)
-                    continue
-
-                # take part after the =
+                if line.startswith('#'): configtmp.write(line) ; continue
                 try:
                     keyword = line.split('=')[0].strip()
                     curitem = keyword
-                except IndexError:
-                    configtmp.write(line)
-                    continue
-
-                # write JSON string of data
+                except IndexError: configtmp.write(line) ; continue
                 if self.has_key(keyword):
                     configtmp.write('%s = %s\n' % (keyword, dumps(self[keyword])))
                     written.append(keyword)
-                else:
-                    configtmp.write(line)
-
-            # write data not found in original config file
+                else: configtmp.write(line)
             for keyword, value in self.iteritems():
-                if keyword in written:
-                    continue
+                if keyword in written: continue
                 curitem = keyword
                 configtmp.write('%s = %s\n' % (keyword, dumps(value)))
-
-            # move temp file to original
             configtmp.close()
-            try:
-                os.rename(self.cfile + '.tmp', self.cfile)
+            try: os.rename(self.cfile + '.tmp', self.cfile)
             except WindowsError:
-                # no atomic operation supported on windows! error is thrown when destination exists
                 os.remove(self.cfile)
                 os.rename(self.cfile + '.tmp', self.cfile)
             self.lock.release()
@@ -213,71 +138,38 @@ class Config(dict):
 
         except Exception, ex:
             print "ERROR WRITING %s CONFIG FILE: %s .. %s" % (self.cfile, str(ex), curitem)
-            try:
-                self.lock.release()
-            except:
-                pass
-            return
+            try: self.lock.release()
+            except: pass
 
     def reload(self):
-
-        """
-            reload the config file.
-
-            .. literalinclude:: ../../gozerbot/config.py
-                :pyobject: Config.reload
-
-
-        """
-
+        """ reload the config file. """
         curline = ""
-
-        # read file and set config values to loaded JSON entries
         try:
-
-            # open file
             f = open(self.cfile, 'r')
-
-            # loop over data in config file            
             for line in f:
                 curline = line
                 line = line.strip()
-                if not line or line.startswith('#'):
-                    continue
+                if not line or line.startswith('#'): continue
                 else:
                     key, value = line.split('=', 1)
                     self[key.strip()] = loads(unicode(value.strip()))
-
-        except IOError:
-            pass
-        except Exception, ex:
-            print "ERROR READING %s CONFIG FILE: %s .. %s" % (self.cfile, str(ex), curline)
+        except IOError: pass
+        except Exception, ex: print "ERROR READING %s CONFIG FILE: %s .. %s" % (self.cfile, str(ex), curline)
 
     def write_init(self, txt):
-
         """ 
             write initial version of the config file .. mainconfig or fleet
             config.
 
-            :param txt: txt to write to config file
-            :type txt: string
-
-            .. literalinclude:: ../../gozerbot/config.py
-                :pyobject: Config.write_init
-
-
         """
-        if hasattr(os, 'mkdir'):
-            # check if datadir is there .. if not create it
-            if not os.path.isdir(self.dir):
-                os.mkdir(self.dir)
+        if not os.path.isdir(self.dir): os.mkdir(self.dir)
+        if not os.path.isfile(self.cfile):
+            cfgfile = open(self.cfile, 'w')
+            cfgfile.write(txt)
+            cfgfile.close()
 
-            # check if config file is already there .. if not init it 
-            if not os.path.isfile(self.cfile):
-                cfgfile = open(self.cfile, 'w')
-                cfgfile.write(txt)
-                cfgfile.close()
 
+## config template strings
 
 mainconfigtxt = """# gozerbot config
 #
@@ -296,7 +188,7 @@ loglevel = 10
 loglist = []
 
 # quit message
-quitmsg = "http://gozerbot.googlecode.com"
+quitmsg = "http://pikacode.com/bthate/gozerbot"
 
 # botterdata dir mask
 mask = "700"
@@ -306,7 +198,6 @@ debug = 0
 
 # database stuff
 
-nodb = 0
 db_driver = "olddb"
 dbtype = "sqlite"
 dbname = "db/main.db"
@@ -318,9 +209,6 @@ dbpasswd = "mekker2"
 
 #jsonuser = "users.json"
 
-# loadlist
-loadlist = ["alias", "all", "at", "chanperm", "choice", "code", "core", "count", "fleet", "googletalk", "grep", "ignore", "irc", "jabber", "job", "misc", "nickcapture", "nickserv", "not", "quote", "reload", "rest", "reverse", "size", "sort", "tail", "tell", "to", "underauth", "uniq", "user", "userstate", "plug", "test", "stats", "inform", "admin", "throttle", "mysqlkeepalive", "gozernet"]
-
 # chars used to seperate result
 dotchars = " .. "
 
@@ -330,7 +218,7 @@ floodallow = 2
 
 # auto register new users 
 
-auto_register = 0
+auto_register = 1
 
 # resource used by xmpp bot (global)
 resource = "gozerbot"
@@ -395,7 +283,7 @@ realname = "GOZERBOT"
 defaultcc = "!"
 
 # quit message
-quitmsg = "http://gozerbot.googlecode.com"
+quitmsg = "http://pikacode.com/bthate/gozerbot"
 
 # bindhost .. uncomment to enable
 bindhost = ""
@@ -408,7 +296,7 @@ nickservpass = ""
 nickservtxt = ["set unfiltered on"]
 
 # allow every command except OPER commands
-auto_register = 0
+auto_register = 1
 
 # strip ident string
 stripident = 0
@@ -417,9 +305,6 @@ loadlist = []
 
 """
 
-# INIT SECTION
+## defines
 
-# main config object
 config = Config(filename='mainconfig', inittxt=mainconfigtxt)
-
-# END INIT
