@@ -4,13 +4,10 @@
 
 """ gozerbot's finaliser """
 
-__copyright__ = 'this file is in the public domain'
+__status__ = "ok"
 
-# ==============
-# IMPORT SECTION
+## gozerbot imports
 
-
-# gozerbot imports
 from utils.log import rlog
 from utils.trace import whichmodule
 from eventhandler import mainhandler
@@ -20,37 +17,20 @@ from persist.persist import saving
 from runner import runners_stop
 from gozerbot.config import config
 
-# basic imports
-import atexit, os, time, sys
+## basic imports
 
-# END IMPORT
-# ==========
+import atexit
+import os
+import time
+import sys
 
-# ============
-# LOCK SECTION
-
-# no locks
-
-# END LOCK
-# ========
+## globalshutdown function
 
 def globalshutdown():
-
-    """
-        shutdown the bot.
-
-        .. literalinclude:: ../../gozerbot/exit.py
-            :pyobject: globalshutdown
-
-    """
-
+    """ shutdown the bot. """
     rlog(10, 'GOZERBOT', 'SHUTTING DOWN')
-
-    try:
-        os.remove('gozerbot.pid')
-    except:
-        pass
-
+    try: os.remove('gozerbot.pid')
+    except: pass
     try:
         runners_stop()
         rlog(10, 'gozerbot', 'shutting down fleet')
@@ -59,15 +39,5 @@ def globalshutdown():
         plugins.exit()
         rlog(10, 'GOZERBOT', 'done')
         os._exit(0)
+    except Exception, ex: rlog(10, 'gozerbot.exit', 'exit error %s:' % str(ex))
 
-    except Exception, ex:
-        rlog(10, 'gozerbot.exit', 'exit error %s:' % str(ex))
-
-# ============
-# INIT SECTION
-
-# register shutdown function
-#atexit.register(globalshutdown)
-
-# END INIT
-# ========
