@@ -4,8 +4,9 @@
 
 """ utils stub for backwards compatibility. """
 
-# ==============
-# IMPORT SECTION
+__status__ = "ok"
+
+## gozerbot imports
 
 from utils.log import *
 from utils.generic import *
@@ -18,14 +19,3 @@ from utils.trace import *
 from utils.locking import *
 from utils.rsslist import *
 from utils.url import *
-
-# END IMPORT
-# ==========
-
-# =========
-# LOCK SECTION
-
-# no locks
-
-# END LOCK
-# ========
