@@ -5,45 +5,48 @@
 
 """ an ircevent is extracted from the IRC string received from the server. """
 
-__copyright__ = 'this file is in the public domain'
+__status__ = "seen"
+
+## gozerbot imports
 
-# gozerbot imports
 from gozerbot.utils.log import rlog
 from gozerbot.utils.generic import fix_format, toenc, fromenc, stripident
 from gozerbot.eventbase import EventBase, makeargrest
 from gozerbot.stats import stats
 from gozerbot.config import config
 
-# basic imports
-import time, re, types, copy
+## basic imports
+
+import time
+import re
+import types
+import copy
+
+## defines1
 
 cpy = copy.deepcopy
 
 try:
     dotchars = config['dotchars']
-    if not dotchars:
-        dotchars = ' .. '
-except KeyError:
-    dotchars = ' .. '
+    if not dotchars: dotchars = ' .. '
+except KeyError: dotchars = ' .. '
+
+## makeargrest function
 
 def makeargrest(ievent):
-
-    """ create ievent.args and ievent.rest .. this is needed because \
-         ircevents might be created outside the parse() function.
     """ 
+         create ievent.args and ievent.rest .. this is needed because
+         ircevents might be created outside the parse() function.
 
-    try:
-        ievent.args = ievent.txt.split()[1:]
-    except ValueError:
-        ievent.args = []
-
-    try:
-        cmnd, ievent.rest = ievent.txt.split(' ', 1)
-    except ValueError:
-        ievent.rest = ""   
-
+    """ 
+    try: ievent.args = ievent.txt.split()[1:]
+    except ValueError: ievent.args = []
+    try: cmnd, ievent.rest = ievent.txt.split(' ', 1)
+    except ValueError: ievent.rest = ""   
     ievent.command = ievent.txt.split(' ')[0]
 
+## Ircevent class
+
 class Ircevent(EventBase):
 
     """ represents an IRC event. """
@@ -58,286 +61,157 @@ class Ircevent(EventBase):
         pass
 
     def parse(self, bot, rawstr):
-
         """ parse raw string into ircevent. """
-
         self.bot = bot
         stats.up('events', bot.name)
         bot.nrevents += 1 
         rawstr = rawstr.rstrip()
         splitted = re.split('\s+', rawstr)
-
-        # check if there is a prefix (: in front)
         if not rawstr[0] == ':':
-            # no prefix .. 1st word is command
             splitted.insert(0, ":none!none@none")
             rawstr = ":none!none@none " + rawstr
-
         self.prefix = splitted[0][1:]
-
-        # get nick/userhost
         nickuser = self.prefix.split('!')
         if len(nickuser) == 2:
             self.nick = nickuser[0]
             stats.up('events', self.nick)
-            if self.bot.cfg['stripident'] or config['stripident']:
-                self.userhost = stripident(nickuser[1])
-            else:
-                self.userhost = nickuser[1]
-
-        # set command
+            if self.bot.cfg['stripident'] or config['stripident']: self.userhost = stripident(nickuser[1])
+            else: self.userhost = nickuser[1]
         self.cmnd = splitted[1]
         self.cbtype = self.cmnd
         stats.up('events', self.cmnd)
-
-        # split string based of postfix count .. nr of items ater the command
         if pfc.has_key(self.cmnd):
             self.arguments = splitted[2:pfc[self.cmnd]+2]
             txtsplit = re.split('\s+', rawstr, pfc[self.cmnd]+2)
             self.txt = txtsplit[-1]
-        else:
-            self.arguments = splitted[2:]
-
-        # 1st argument is target
-        if self.arguments:
-            self.target = self.arguments[0]
+        else: self.arguments = splitted[2:]
+        if self.arguments: self.target = self.arguments[0]
         self.postfix = ' '.join(self.arguments)
-
-        # check if target is text
-        if self.target and self.target.startswith(':'):
-            self.txt = ' '.join(self.arguments)
-
-        # strip strarting ':' from txt
-        if self.txt:
-            if self.txt[0] == ":":
-                self.txt = self.txt[1:]
+        if self.target and self.target.startswith(':'): self.txt = ' '.join(self.arguments)
+        if self.txt and self.txt[0] == ":": self.txt = self.txt[1:]
         rlog(0, 'ircevent',"%s %s %s" % (self.cmnd, self.arguments, self.txt))
-
-        # set ircevent attributes
-        if self.cmnd == 'PING':
-            self.speed = 10
+        if self.cmnd == 'PING': self.speed = 10
         if self.cmnd == 'PRIVMSG':
             self.channel = self.arguments[0]
-            if '\001' in self.txt:
-                self.isctcp = True
+            if '\001' in self.txt: self.isctcp = True
         elif self.cmnd == 'JOIN' or self.cmnd == 'PART':
-            if self.arguments:
-                self.channel = self.arguments[0]
-            else:
-                self.channel = self.txt
-        elif self.cmnd == 'MODE':
-            self.channel = self.arguments[0]
-        elif self.cmnd == 'TOPIC':
-            self.channel = self.arguments[0]
-        elif self.cmnd == 'KICK':
-            self.channel = self.arguments[0]
-        elif self.cmnd == '353':
-            self.channel = self.arguments[2]
-        elif self.cmnd == '324':
-            self.channel = self.arguments[1]
+            if self.arguments: self.channel = self.arguments[0]
+            else: self.channel = self.txt
+        elif self.cmnd == 'MODE': self.channel = self.arguments[0]
+        elif self.cmnd == 'TOPIC': self.channel = self.arguments[0]
+        elif self.cmnd == 'KICK': self.channel = self.arguments[0]
+        elif self.cmnd == '353': self.channel = self.arguments[2]
+        elif self.cmnd == '324': self.channel = self.arguments[1]
         if self.userhost:
-            # userhost before possible stripident
             self.ruserhost = self.userhost
-            # jabber compat .. this is userhost on irc
             self.stripped = self.userhost
-            # determine user
             self.user = stripident(self.userhost).split('@')[0]
-
         self.origtxt = self.txt
         self.channel = self.channel.strip()
         stats.up('events', self.channel)
         self.origchannel = self.channel
         rlog(-1, 'ircevent', self)
-
-        # show error
         try:
             nr = int(self.cmnd)
-            if nr > 399:
-                rlog(10, bot.name + '.error', '%s: %s %s' % (self.cmnd, \
-self.arguments, self.txt))
-        except ValueError:
-            pass
-
+            if nr > 399: rlog(10, bot.name + '.error', '%s: %s %s' % (self.cmnd, self.arguments, self.txt))
+        except ValueError: pass
         return self
 
     def reply(self, txt, result=None, nick=None, dot=False, nritems=False, nr=False, fromm=None, private=False, how=''):
-
-        # don't replu is result is empty list
-        if result == []:
-            return
-
-        # stats
+        """ send reply to the channel the event originated from. """
+        if result == []: return
         stats.up('events', 'replies')
         if not how:
-            try:
-                how = self.options['--how']        
-            except KeyError:
-                how = 'msg'
-
-        # init
+            try: how = self.options['--how']        
+            except KeyError: how = 'msg'
         restxt = ""
         splitted = []
-
-        # make reply if result is a dict
         if type(result) == types.DictType:
             for i, j in result.iteritems():
                 if type(j) == types.ListType:
-                    try:
-                        z = dotchars.join(j)
-                    except TypeError:
-                        z = unicode(j)
-                else:
-                    z = j
+                    try: z = dotchars.join(j)
+                    except TypeError: z = unicode(j)
+                else: z = j
                 res = "%s: %s" % (i, z)
                 splitted.append(res)
-                if dot == True:
-                    restxt += "%s%s" % (res, dotchars)
-                else:
-                    restxt += "%s %s" % (dot or ' ', res)
+                if dot == True: restxt += "%s%s" % (res, dotchars)
+                else: restxt += "%s %s" % (dot or ' ', res)
             if restxt:
-                if dot == True:
-                    restxt = restxt[:-6]
-                elif dot:
-                    restxt = restxt[:-len(dot)]
-
+                if dot == True: restxt = restxt[:-6]
+                elif dot: restxt = restxt[:-len(dot)]
         lt = False # set if result is list
-
-        # set vars if result is a list
         if type(txt) == types.ListType and not result:
             result = txt
             origtxt = u""
             lt = True
-        else:
-            origtxt = txt
-
-        if result:
-            lt = True
-
-        # if queues are set write output to them
+        else: origtxt = txt
+        if result: lt = True
         if self.queues:
             for i in self.queues:
                 if splitted:
-                    for item in splitted:
-                        i.put_nowait(item)
+                    for item in splitted: i.put_nowait(item)
                 elif lt:
-                    for j in result:
-                        i.put_nowait(j)
-                elif restxt:
-                    i.put_nowait(restxt)
-                else:
-                    i.put_nowait(txt)
-            if self.onlyqueues:
-                return
-
-        # check if bot is set in event
-        if not self.bot:
-            rlog(10, 'event', 'no bot defined in event')
-            return
-
-        # make response
+                    for j in result: i.put_nowait(j)
+                elif restxt: i.put_nowait(restxt)
+                else: i.put_nowait(txt)
+            if self.onlyqueues: return
+        if not self.bot: rlog(10, 'event', 'no bot defined in event') ; return
         pretxt = origtxt
         if lt and not restxt:
             res = []
-
-            # check if there are list in list
             for i in result:
                 if type(i) == types.ListType or type(i) == types.TupleType:
-                    try:
-                        res.append(dotchars.join(i))
-                    except TypeError:
-                        res.extend(i)
-                else:
-                    res.append(i)
-
-            # if nritems is set ..
+                    try: res.append(dotchars.join(i))
+                    except TypeError: res.extend(i)
+                else: res.append(i)
             result = res
             if nritems:
-                if len(result) > 1:
-                    pretxt += "(%s items) .. " % len(result)
+                if len(result) > 1: pretxt += "(%s items) .. " % len(result)
             txtlist = result
-
-            # prepend item number for results
             if not nr is False:
-                try:
-                    start = int(nr)
-                except ValueError:
-                    start = 0
+                try: start = int(nr)
+                except ValueError: start = 0
                 txtlist2 = []
                 teller = start
                 for i in txtlist:
                     txtlist2.append(u"%s) %s" % (teller, i))
                     teller += 1
                 txtlist = txtlist2
-
-            # convert results to encoding
             txtl = []
-            for item in txtlist:
-                txtl.append(toenc(item))
+            for item in txtlist: txtl.append(toenc(item))
             txtlist = txtl
-
-            # join result with dot 
-            if dot == True:
-                restxt = dotchars.join(txtlist)
-            elif dot:
-                restxt = dot.join(txtlist)
-            else:
-                restxt = ' '.join(txtlist)
-
-        # see if txt needs to be prepended
+            if dot == True: restxt = dotchars.join(txtlist)
+            elif dot: restxt = dot.join(txtlist)
+            else: restxt = ' '.join(txtlist)
         if pretxt:
-            try:
-                restxt = pretxt + restxt
-            except TypeError:
-                rlog(10, 'eventbase', "can't add %s and %s" % (str(pretxt), str(restxt)))
-
-        # if txt in result is filtered ignore the reuslt
-        if self.filtered(restxt):
-            return
-
-        # if event is DCC based write result directly to socket
+            try: restxt = pretxt + restxt
+            except TypeError: rlog(10, 'eventbase', "can't add %s and %s" % (str(pretxt), str(restxt)))
+        if self.filtered(restxt): return
         if self.cmnd == 'DCC' and self.sock:
             self.bot.say(self.sock, restxt, speed=self.speed, how=how)
             return
-
-        # if nick is set write result to nick in question
         if nick:
             self.bot.say(nick, restxt, fromm=nick, speed=self.speed, how=how)
             return
-
-        # if originatiog event is a private message or private flaf is set 
         if self.msg or private:
             self.bot.say(self.nick, restxt, fromm=self.nick, speed=self.speed, how=how)
             return
-
-        # check if bot is in silent mode .. if so use /msg 
         silent = False
         channel = self.printto or self.channel
-        try:
-            silent = self.bot.channels[channel]['silent']
-        except (KeyError, TypeError):
-            pass
+        try: silent = self.bot.channels[channel]['silent']
+        except (KeyError, TypeError): pass
         fromm = fromm or self.nick
-
-        # check if notice needs to be used
         if silent:
             notice = False
-            try:
-                notice = self.bot.channels[channel]['notice']
-            except (KeyError, TypeError):
-                pass
-            if notice:
-                self.bot.say(self.nick, restxt, how='notice', fromm=fromm, speed=self.speed)
-            else:
-                self.bot.say(self.nick, restxt, fromm=fromm, speed=self.speed, how=how)
+            try: notice = self.bot.channels[channel]['notice']
+            except (KeyError, TypeError): pass
+            if notice: self.bot.say(self.nick, restxt, how='notice', fromm=fromm, speed=self.speed)
+            else: self.bot.say(self.nick, restxt, fromm=fromm, speed=self.speed, how=how)
             return
+        if self.printto: self.bot.say(self.printto, restxt, fromm=fromm, speed=self.speed, how=how) ; return
+        else: self.bot.say(self.channel, restxt, fromm=fromm, speed=self.speed, how=how)
 
-        # if printto is set used that as the target
-        if self.printto:
-            self.bot.say(self.printto, restxt, fromm=fromm, speed=self.speed, how=how)
-            return
-        else:
-            self.bot.say(self.channel, restxt, fromm=fromm, speed=self.speed, how=how)
-
+## defines2
 
 # postfix count aka how many arguments
 
@@ -478,7 +352,6 @@ pfc['491'] = 1
 pfc['501'] = 1
 pfc['502'] = 1
 pfc['700'] = 2
-
                 
 # default event used to initialise events
 defaultevent = EventBase()
