@@ -4,38 +4,29 @@
 
 """ monitors .. call callback on bot output. """
 
-__copyright__ = 'this file is in the public domain'
+__status__ = "seen"
+
+## gozerbot imports
 
 from gozerbot.monitor import Monitor
-
-# gozerbot imports
 from ircevent import Ircevent
 
+## Outmonitor class
+
 class Outmonitor(Monitor):
 
     """ monitor for bot output (bot.send). """
 
     def handle(self, bot, txt):
-
         """ fire outmonitor callbacks. """
-
         ievent = Ircevent().parse(bot, txt)
-
-        if not ievent:
-            rlog(10, 'monitor', "can't make ircevent: %s" % txt)
-            return
-
+        if not ievent: rlog(10, 'monitor', "can't make ircevent: %s" % txt) ; return
         ievent.nick = bot.nick
-
-        try:
-            ievent.userhost = bot.userhosts.data[bot.nick]
-        except KeyError:
-            ievent.userhost = "bot@bot"
-
+        try: ievent.userhost = bot.userhosts.data[bot.nick]
+        except KeyError: ievent.userhost = "bot@bot"
         Monitor.handle(self, bot, ievent)
 
-# bot.send() monitor
-outmonitor = Outmonitor('outmonitor') 
+## defines
 
-# bot.say() monitor
+outmonitor = Outmonitor('outmonitor') 
 saymonitor = Monitor('saymonitor')
