@@ -4,26 +4,25 @@
 
 """ count number of items in result queue. """
 
-__copyright__ = 'this file is in the public domain'
+__status__ = "seen"
+
+## gozerbot imports
 
-# gozerbot imports
 from gozerbot.commands import cmnds
 from gozerbot.utils.generic import waitforqueue
 from gozerbot.examples import examples
 from gozerbot.plughelp import plughelp
 from gozerbot.tests import tests
 
-plughelp.add('count', 'the count command counts the number of results in a \
-pipeline')
+## plughelp
+
+plughelp.add('count', 'the count command counts the number of results in a pipeline')
+
+## count command
 
 def handle_count(bot, ievent):
-
-    """ show nr of elements in result list. """
-
-    if not ievent.inqueue:
-        ievent.reply("use count in a pipeline")
-        return
-
+    """ no arguments - show nr of elements in result list. """
+    if not ievent.inqueue: ievent.reply("use count in a pipeline") ; return
     result = waitforqueue(ievent.inqueue, 5)
     ievent.reply(str(len(result)))
 
