@@ -4,9 +4,10 @@
 
 """ show sizes of plugin data. """
 
-__copyright__ = 'this file is in the public domain'
+__status__ = "seen"
+
+## gozerbot imports
 
-# gozerbot imports
 from gozerbot.commands import cmnds
 from gozerbot.examples import examples
 from gozerbot.users import users
@@ -18,13 +19,14 @@ from gozerbot.fleet import fleet
 from gozerbot.plughelp import plughelp
 from gozerbot.tests import tests
 
-plughelp.add('size', 'the size command shows the sizes of plugins that \
-provide a size() plugin command and the sizes of some basic structures')
+## plughelp
+
+plughelp.add('size', 'the size command shows the sizes of plugins that provide a size() plugin command and the sizes of some basic structures')
+
+## size command
 
 def handle_size(bot, ievent):
-
     """ size .. show size of core datastructures  and plugins that provide a size() function. """
-
     txtlist = []
     txtlist.append("fleet: %s" % fleet.size())
     txtlist.append("users: %s" % users.size())
@@ -34,12 +36,8 @@ def handle_size(bot, ievent):
     txtlist.append("reafter: %s" % reafter.size())
     txtlist.append("aliases: %s" % len(aliases.data))
     txtlist.append("examples: %s" % examples.size()) 
-
     plugsizes = plugins.plugsizes()
-
-    if plugsizes:
-        txtlist += plugsizes
-
+    if plugsizes: txtlist += plugsizes
     ievent.reply(txtlist)
 
 cmnds.add('size', handle_size, ['USER', 'WEB'])
