@@ -1,10 +1,12 @@
-# jsb/runner.py
+# gozerbot/runner.py
 #
 #
 
 """ threads management to run jobs. """
 
-## jsb imports
+__status__ = "seen"
+
+## gozerbot imports
 
 from gozerbot.threads.thr import getname, start_new_thread, start_bot_command
 from gozerbot.utils.generic import handle_exception
@@ -45,18 +47,14 @@ class Runner(RunnerLoop):
         self.working = True
         name = getname(str(func))
         try:
-            #rlockmanager.acquire(getname(str(func)))
             name = getname(str(func))
             self.name = name
-            rlog(10, "runner", 'running %s: %s' % (descr, name))
+            rlog(9, "runner", 'running %s: %s' % (descr, name))
             self.starttime = time.time()
             func(*args, **kwargs)
             self.finished = time.time()
             self.elapsed = self.finished - self.starttime
-            #if self.elapsed > 3:
-                #logging.debug('ALERT %s %s job taking too long: %s seconds' % (descr, str(func), self.elapsed))
         except Exception, ex: handle_exception()
-        #finally: rlockmanager.release()
         self.working = False
 
 ## BotEventRunner class
@@ -67,26 +65,15 @@ class BotEventRunner(Runner):
         """ schedule a bot command. """
         try:
             self.starttime = time.time()
-            #lockmanager.acquire(getname(str(func)))
             name = getname(str(func))
             self.name = name
             self.working = True
-            rlog(10, "runner", "now running %s" % name)
+            rlog(9, "runner", "now running %s" % name)
             func(bot, ievent, *args, **kwargs)
-
-            for queue in ievent.queues:
-                queue.put_nowait(None)
-
+            for queue in ievent.queues: queue.put_nowait(None)
             self.finished = time.time()
             self.elapsed = self.finished - self.starttime
-            #if self.elapsed > 3:
-            #    logging.info('ALERT %s %s job taking too long: %s seconds' % (descr, str(func), self.elapsed))
-            #if ievent.iscommand: ievent.ready()
-            #if not ievent.type == "OUTPUT" and not ievent.dontclose: ievent.ready()
-            #time.sleep(0.001)
-        except Exception, ex:
-            handle_exception(ievent)
-        #finally: lockmanager.release(getname(str(func)))
+        except Exception, ex: handle_exception(ievent)
         self.working = False
         self.name = "finished"
 
@@ -118,11 +105,8 @@ class Runners(object):
  
     def put(self, *data):
         """ put a job on a free runner. """
-        #logging.debug("size is %s" % len(self.runners))
         for runner in self.runners:
-            if not runner.queue.qsize():
-                runner.put(*data)
-                return
+            if not runner.queue.qsize(): runner.put(*data) ; return
         runner = self.makenew()
         runner.put(*data)
          
@@ -147,17 +131,14 @@ class Runners(object):
 
     def cleanup(self):
         """ clean up idle runners. """
-        #if not len(self.runners): logging.debug("nothing to clean")
         for index in range(len(self.runners)-1, -1, -1):
             runner = self.runners[index]
-            #logging.debug("cleanup %s" % runner.name)
             if not runner.queue.qsize():
                 try: runner.stop() ; del self.runners[index]
                 except IndexError: pass
                 except: handle_exception()
-            #else: logging.info("now running: %s" % runner.nowrunning)
 
-## global runners
+## defines
 
 cmndrunners = defaultrunner = longrunner = Runners(50, BotEventRunner)
 cbrunners = Runners(100, BotEventRunner, doready=False)
@@ -165,8 +146,6 @@ waitrunners = Runners(10, Runner)
 
 ## runners_start
 
-def runners_start():
-    pass
+def runners_start(): pass
 
-def runners_stop():
-    pass
+def runners_stop(): pass
