@@ -4,17 +4,13 @@
 
 """ maintain bot stats. """
 
-## IMPORT SECTION
+__status__ = "seen"
+
+## gozerbot imports
 
 from gozerbot.utils.statdict import Statdict
 
-## END IMPORT
-
-## LOCK SECTION
-
-# no locks
-
-## END LOCK
+## GozerStats class
 
 class GozerStats(object):
 
@@ -24,44 +20,27 @@ class GozerStats(object):
         self.data = {}
 
     def init(self, item):
-
         """ initialize a stats item. """
-
         self.data[item] = Statdict()
 
     def up(self, item, issue):
-
         """ up a stats item. """
-
-        if not self.data.has_key(item):
-            self.init(item)
+        if not self.data.has_key(item): self.init(item)
         self.data[item].upitem(issue)
 
     def get(self, item):
-
         """ return stats item. """
-
-        try:
-            return self.data[item]
-        except KeyError:
-            return 
+        try: return self.data[item]
+        except KeyError: return 
 
     def list(self, item):
-
         """ list all stats belonging to item. """
-
-        if self.data.has_key(item):
-            return self.data[item].keys()
+        if self.data.has_key(item): return self.data[item].keys()
 
     def all(self):
-
         """ list all stats items. """
-
         return self.data.keys()
 
-## INIT SECTION
+## defines
 
-# the gozerbot stats object
 stats = GozerStats()
-
-## END INIT
