@@ -1,10 +1,12 @@
-# gozerbot/dol.py
+# gozerbot/utils/dol.py
 #
 #
 
 """ dict of lists """
 
-__copyright__ = 'this file is in the public domain'
+__status__ = "seen"
+
+## Dol class
 
 class Dol(dict):
 
@@ -12,25 +14,19 @@ class Dol(dict):
 
     def insert(self, nr, item, issue):
         """ add issue to item entry """
-        if self.has_key(item):
-            self[item].insert(nr, issue)
-        else:
-            self[item] = [issue]
+        if self.has_key(item): self[item].insert(nr, issue)
+        else: self[item] = [issue]
         return 1
 
     def add(self, item, issue):
         """ add issue to item entry """
-        if self.has_key(item):
-            self[item].append(issue)
-        else:
-            self[item] = [issue]
+        if self.has_key(item): self[item].append(issue)
+        else: self[item] = [issue]
         return 1
 
     def adduniq(self, item, issue):
         """ only add issue to item if it is not already there """
-        if self.has_key(item):
-            if issue in self[item]:
-                return 0
+        if self.has_key(item) and issue in self[item]: return 0
         self.add(item, issue)
         return 1
             
@@ -38,26 +34,19 @@ class Dol(dict):
         """ del self[item][number] """
         number = int(number)
         if self.has_key(item):
-            try:
-                del self[item][number]
-                return 1
-            except IndexError:
-                return None
+            try: del self[item][number] ; return 1
+            except IndexError: return None
 
     def remove(self, item, issue):
         """ remove issue from item """
-        try:
-            self[item].remove(issue)
-            return 1
-        except ValueError:
-            pass
+        try: self[item].remove(issue) ; return 1
+        except ValueError: pass
 
     def has(self, item, issue):
         """ check if item has issue """
         try:
-            if issue in self[item]:
-                return 1
-            else:
-                return None
-        except KeyError:
-            pass
+            if issue in self[item]: return 1
+            else: return None
+        except KeyError: pass
+
+#### BHJTW 22-01-2012
\ No newline at end of file
