@@ -4,7 +4,7 @@
 
 """ limited list """
 
-__copyright__ = 'this file is in the public domain'
+__status__ = "seen"
 
 class Limlist(list):
 
@@ -16,14 +16,13 @@ class Limlist(list):
 
     def insert(self, index, item):
         """ insert item at index .. pop oldest item if limit is reached """
-        if index > len(self):
-            return -1
-        if len(self) >= self.limit:
-            self.pop(len(self)-1)
+        if index > len(self): return -1
+        if len(self) >= self.limit: self.pop(len(self)-1)
         list.insert(self, index, item)
 
     def append(self, item):
         """ add item to list .. pop oldest item if limit is reached """
-        if len(self) >= self.limit:
-            self.pop(0)
+        if len(self) >= self.limit: self.pop(0)
         list.append(self, item)
+
+#### BHJTW 22-01-2012
