@@ -4,11 +4,18 @@
 
 """ manages locks """
 
-__copyright__ = 'this file is in the public domain'
+__status__ = "seen"
+
+## gozerbot imports
 
 from log import rlog
+
+## basic imports
+
 import thread, threading
 
+## Lockmananger class
+
 class Lockmanager(object):
 
     """ place to hold locks """
@@ -23,19 +30,16 @@ class Lockmanager(object):
         
     def get(self, name):
         """ get lock """
-        if not self.locks.has_key(name):
-            self.allocate(name)
+        if not self.locks.has_key(name): self.allocate(name)
         return self.locks[name]
         
     def delete(self, name):
         """ delete lock """
-        if self.locks.has_key(name):
-            del self.locks[name]
+        if self.locks.has_key(name): del self.locks[name]
 
     def acquire(self, name):
         """ acquire lock """
-        if not self.locks.has_key(name):
-            self.allocate(name)
+        if not self.locks.has_key(name): self.allocate(name)
         rlog(0, 'lockmanager', 'acquire %s' % name)
         self.locks[name].acquire()
 
@@ -44,6 +48,7 @@ class Lockmanager(object):
         rlog(0, 'lockmanager', 'releasing %s' % name)
         self.locks[name].release()
 
+## RLockManager class
 
 class RLockManager(Lockmanager):
 
@@ -52,5 +57,9 @@ class RLockManager(Lockmanager):
         self.locks[name] = threading.RLock()
         rlog(0, 'lockmanager', 'allocated RLock %s' % name)
 
+## defines
+
 lockmanager = Lockmanager()
 rlockmanager = RLockManager()
+
+#### BHJTW 22-01-2012
