@@ -2,36 +2,44 @@
 #
 #
 
-""" gozerbots logging module. logging is implemented with the use of a 
+""" 
+    gozerbots logging module. logging is implemented with the use of a 
     loglevel and a loglist of plugins to log for. 
+
 """
 
+__status__ = "seen"
+
 # basic imports
 
 from trace import whichmodule
-import logging, logging.handlers, sys, traceback, os, thread
+import logging
+import logging.handlers
+import sys
+import traceback
+import os
+import thread
 
 # basic logger
-logging.basicConfig(level=logging.INFO, format="[%(asctime)s] (%(name)s) %(message)s")
 
+logging.basicConfig(level=logging.INFO, format="[%(asctime)s] (%(name)s) %(message)s")
 basiclogger = logging.getLogger('')
 
-# check if we are in GAE
+## make sure dirs are there
 
-# make sure dirs are there
-if not os.path.isdir('logs'):
-    os.mkdir('logs')
-if not os.path.isdir('logs' + os.sep + 'bot'):
-    os.mkdir('logs' + os.sep + 'bot')
+if not os.path.isdir('logs'): os.mkdir('logs')
+if not os.path.isdir('logs' + os.sep + 'bot'): os.mkdir('logs' + os.sep + 'bot')
+
+## add logging to file
 
-# add logging to file
 filehandler = logging.handlers.TimedRotatingFileHandler(
               'logs' + os.sep + 'bot' + os.sep + 'gozerbot.log', 'midnight')
 formatter = logging.Formatter("[%(asctime)s] (%(name)s) %(message)s")
 filehandler.setFormatter(formatter)
 basiclogger.addHandler(filehandler)
 
-# the vars
+## defines
+
 loglevel = 10
 logcallbacks = []
 loglist = []
@@ -39,10 +47,12 @@ logfile = None
 enabled = True
 debuglog = False
 
-# lock
+## locks
 
 loglock = thread.allocate_lock()
 
+## exceptionmsg function
+
 def exceptionmsg():
     """ create a exception traceback as 1 liner. """
     exctype, excvalue, tb = sys.exc_info()
@@ -56,45 +66,34 @@ def exceptionmsg():
     del trace
     return "%s%s: %s" % (result, exctype, excvalue)
 
+## rlog function
+
 def rlog(level, descr, txt):
-    """ log an item showing description and txt. call logcallbacks if 
-        available
-    """
-    if not enabled:
-        return
+    """ log an item showing description and txt. call logcallbacks if available. """
+    if not enabled: return
     try:
-        #loglock.acquire()
         logger = logging.getLogger(descr)
-
         go = False
-
         if loglist:
-
             for item in loglist:
-
-                if item in descr:
-                    go = True
-
+                if item in descr: go = True
         if level >= loglevel or loglist and go:
-            if debuglog:
-                logger.info("(%s) %s - <%s>" % (descr, txt, whichmodule(2)))
-            else:
-                logger.info(txt)
-                         
+            if debuglog: logger.info("(%s) %s - <%s>" % (descr, txt, whichmodule(2)))
+            else: logger.info(txt)
             for cb in logcallbacks:
+                try: cb(level, descr, txt)
+                except: print exceptionmsg()
+    except (IOError, OSError): pass
 
-                try:
-                    cb(level, descr, txt)
-                except:
-                    print exceptionmsg()
+## disable_logging function
 
-    except (IOError, OSError):
-        pass
-        
 def disable_logging():
+    """ disable logging. """
     global enabled
     enabled = False
 
+## enable_logging function
+
 def enable_logging(level=10, list=[]):
     """ enable logging setting loglevel and/ort loglist """
     global loglevel, loglist, enabled
@@ -102,3 +101,5 @@ def enable_logging(level=10, list=[]):
     loglevel = level
     loglist = list
     enabled = True
+
+#### BHJTW 22-01-2012
