@@ -4,6 +4,8 @@
 
 """ name related helper functions. """
 
+__status__ = "seen"
+
 ## basic imports
 
 import string
@@ -18,7 +20,8 @@ allowednamechars = string.ascii_letters + string.digits + '!.@-'
 def stripname(txt):
     res = ""
     for c in txt:
-        if c in allowednamechars:
-            res += c
+        if c in allowednamechars: res += c
     res.replace(os.sep, '-')
     return res
+
+#### BHJTW 22-01-2012
