@@ -1,13 +1,17 @@
-# gozerbot/nextid.py
+# gozerbot/utils/nextid.py
 #
 #
 
 """ provide increasing counters """
 
-__copyright__ = 'this file is in the public domain'
+__status__ = "seen"
+
+## basic imports
 
 import os
 
+## Nextid class
+
 class Nextid(object):
 
     """ counters by name """
@@ -18,39 +22,31 @@ class Nextid(object):
     def get(self, item):
         """ get counter for item """
         item = item.lower()
-        try:
-            result = self.data[item]
-        except KeyError:
-            return None 
+        try: result = self.data[item]
+        except KeyError: return None 
         return result
 
     def set(self, item, number):
         """ set counter of item to number """
         item = item.lower()
-        try:
-            self.data[item] = int(number)
-        except ValueError:
-            return 0
+        try: self.data[item] = int(number)
+        except ValueError: return 0
         self.save()
         return 1
 
     def next(self, item):
         """ get increment of item counter """
         item = item.lower()
-        try:
-            self.data[item] += 1
-        except KeyError:
-            self.data[item] = 1
+        try: self.data[item] += 1
+        except KeyError: self.data[item] = 1
         self.save()
         return self.data[item]
 
     def nextlist(self, item, nr):
         """ get increment of item counter """
         item = item.lower()
-        try:
-            start = self.data[item] + 1
-        except KeyError:
-            start = 1
+        try: start = self.data[item] + 1
+        except KeyError: start = 1
         stop = start + nr
         l = range(start, stop)
         self.data[item] = stop - 1
@@ -60,4 +56,8 @@ class Nextid(object):
     def save(self):
         pass
 
+## defines
+
 nextid = Nextid('notused')
+
+#### BHJTW 22-01-2012
