@@ -4,22 +4,35 @@
 
 """ popen helper functions """
 
-__copyright__ = 'this file is in the public domain'
+__status__ = "seen"
+
+## defines
 
 go = False
 
+## imports
+
 try:
     from subprocess import Popen, PIPE
     from locking import lockdec
-    import thread, StringIO, logging, types
+    import thread
+    import StringIO
+    import logging
+    import types
     go = True
-except:
-    go = False
+except: go = False
+
+## teh stuff
 
 if go:
+
+    ## locks
+
     popenlock = thread.allocate_lock()
     popenlocked = lockdec(popenlock)
 
+    ## PopenWhitelistError exception
+
     class PopenWhitelistError(Exception):
 
         def __init__(self, item):
@@ -29,6 +42,8 @@ if go:
         def __str__(self):
             return self.item
 
+    ## PoperListError exception
+
     class PopenListError(Exception):
 
         def __init__(self, item):
@@ -38,11 +53,15 @@ if go:
         def __str__(self):
             return str(self.item)
 
+    ## GozerStringIO class
+
     class GozerStringIO(StringIO.StringIO):
 
         def readlines(self):
             return self.read().split('\n')
 
+    ## Gozerpopen4 class
+
     class Gozerpopen4(Popen):
 
         def __init__(self, args):
@@ -52,32 +71,23 @@ if go:
             self.errors    = self.stderr
 
         def close(self):
+            """ close the Popen instance. """
             self.wait()
-            try:
-                self.stdin.close()
-            except:
-                pass
-            try:
-                self.stdout.close()
-            except:
-                pass
-            try:
-                self.errors.close()
-            except:
-                pass
+            try: self.stdin.close()
+            except: pass
+            try: self.stdout.close()
+            except: pass
+            try: self.errors.close()
+            except: pass
             return self.returncode
 
     def gozerpopen(args, userargs=[]):
-
-        if type(args) != types.ListType:
-            raise PopenListError(args)
-
-        if type(userargs) != types.ListType:
-            raise PopenListError(args)
-
+        """ call popen via the Gozerpopen4 class. """
+        if type(args) != types.ListType: raise PopenListError(args)
+        if type(userargs) != types.ListType: raise PopenListError(args)
         for i in userargs:
-            if i.startswith('-'):
-                raise PopenWhitelistError(i)
-
+            if i.startswith('-'): raise PopenWhitelistError(i)
         proces = Gozerpopen4(args + userargs)
         return proces
+
+#### BHJTW 22-01-2012
