@@ -1,10 +1,12 @@
-# gozerbot/statdict.py
+# gozerbot/utils/statdict.py
 #
 #
 
 """ stats dict """
 
-__copyright__ = 'this file is in the public domain'
+__status__ = "seen"
+
+## Statdict class
 
 class Statdict(dict):
 
@@ -16,30 +18,25 @@ class Statdict(dict):
 
     def upitem(self, item, value=1):
         """ increase item """
-        if not self.has_key(item):
-            self[item] = value
-            return
+        if not self.has_key(item): self[item] = value ; return
         self[item] += value
 
     def top(self, start=1, limit=None):
         """ return highest items """
         result = []
         for item, value in self.iteritems():
-            if value >= start:
-                result.append((item, value))
+            if value >= start: result.append((item, value))
         result.sort(lambda b, a: cmp(a[1], b[1]))
-        if limit:
-            result =  result[:limit]
+        if limit: result =  result[:limit]
         return result
 
     def down(self, end=100, limit=None):
         """ return lowest items """
         result = []
         for item, value in self.iteritems():
-            if value <= end:
-                result.append((item, value))
+            if value <= end: result.append((item, value))
         result.sort(lambda a, b: cmp(a[1], b[1]))
-        if limit:
-            return result[:limit]
-        else:
-            return result
+        if limit: return result[:limit]
+        else: return result
+
+#### BHJTW 22-01-2012
