@@ -2,14 +2,20 @@
 #
 #
 
+""" xmpp related helper funcions. """
+
+__status__ = "seen"
+
+## basic imports
+
 from xml.etree import cElementTree as ET
 import types
 
+## make_presence function
+
 def make_presence(xml):
     pres = {'subject': '', 'to': '', 'message': '', 'name': '', 'resource': '', 'jid': ''}
-    if type(xml) == types.DictType:
-        pres.update(xml)
-        return pres
+    if type(xml) == types.DictType: pres.update(xml) ; return pres
     et = ET.XMLID(xml)
     pres.update(et[0].items())
     xml = ET.XML(xml)
@@ -17,15 +23,14 @@ def make_presence(xml):
         pres['name'] = pres['from'].split('@')[0]
         pres['resource'] = pres['from'].split('/')[1]
         pres['jid'] = pres['from'].split('/')[0]
-    except KeyError:
-        pass
+    except KeyError: pass
     return pres
 
+## make_message function
+
 def make_message(xml):
     msg = {'subject': '', 'to': '', 'txt': '', 'message': '', 'from': '', 'jid': '', 'name': '', 'resource': ''}
-    if type(xml) == types.DictType:
-        msg.update(xml)
-        return msg
+    if type(xml) == types.DictType: msg.update(xml) ; return msg
     et = ET.XMLID(xml)
     msg.update(et[0].items())
     xml = ET.XML(xml)
@@ -34,3 +39,5 @@ def make_message(xml):
     msg['resource'] = msg['from'].split('/')[1]
     msg['jid'] = msg['from'].split('/')[0]
     return msg
+
+#### BHJTW 22-01-2012
