@@ -1,22 +1,28 @@
-# gozerbot/xmpp/presence.py
+# gozerbot/xmpp/iq.py
 #
 #
 
-""" Iq. """
+""" Iq class. """
+
+__status__ = "seen"
+
+## gozerbot imports
 
-# gozerbot imports
 from gozerbot.eventbase import EventBase
 from gozerbot.utils.trace import whichmodule
 from gozerbot.utils.log import rlog
-
-# xmpp imports
 from core import XMLDict
 
-# basic imports
+## basic imports
+
 import time
+
+## Iq class
  
 class Iq(EventBase):
 
+    """ Iq class implementation. """
+
     def __init__(self, nodedict={}, bot=None):
         rlog(2, whichmodule(1), 'IQ: ' + str(nodedict))
         EventBase.__init__(self, nodedict, bot)
@@ -27,12 +33,8 @@ class Iq(EventBase):
         self.cmnd = 'Iq'
         self.conn = None
         self.arguments = []
-
-        try:
-            self.nick = self.fromm.split('/')[1]
-        except (AttributeError, IndexError):
-            pass
-
+        try: self.nick = self.fromm.split('/')[1]
+        except (AttributeError, IndexError): pass
         self.jid = self.jid or self.fromm
         self.ruserhost = self.jid
         self.userhost = str(self.jid)
@@ -46,11 +48,10 @@ class Iq(EventBase):
         self.rest = ' '.join(self.args)
         self.sock = None
         self.speed = 5
-        if self.type == 'groupchat':
-            self.groupchat = True
-        else:
-            self.groupchat = False
-        if self.txt:
-            makeargrest(self)
+        if self.type == 'groupchat': self.groupchat = True
+        else: self.groupchat = False
+        if self.txt: makeargrest(self)
         self.joined = False
         self.denied = False
+
+#### BHJTW 22-01-2012
