@@ -2,10 +2,18 @@
 #
 #
 
+""" jabber identity class. """
+
+__status__ = "seen"
+
+## exceptions
+
 class InvalidJID(BaseException):
 
     pass
 
+## JID class
+
 class JID(object):
 
     def __init__(self, str):
@@ -16,21 +24,16 @@ class JID(object):
             self.host = ""
             self.resource = ""
             return
-        if not self.validate(str):
-            raise InvalidJID(str)
+        if not self.validate(str): raise InvalidJID(str)
         self.full = str
         self.user = self.full.split('@')[0]
         self.userhost = self.full.split('/')[0]
-        try:
-             self.host = self.userhost.split('@')[1]
-        except (IndexError, ValueError):
-            raise InvalidJID(str)
-            
-        try:
-            self.resource = self.full.split('/')[1]
-        except (IndexError, ValueError):
-            self.resource = u""
+        try: self.host = self.userhost.split('@')[1]
+        except (IndexError, ValueError): raise InvalidJID(str)
+        try: self.resource = self.full.split('/')[1]
+        except (IndexError, ValueError): self.resource = u""
 
     def validate(self, s):
-        if not '#' in s:
-            return True
+        if not '#' in s: return True
+
+#### BHJTW 22-01-2012
