@@ -4,25 +4,25 @@
 
 """ monitors .. call callback on bot output. """
 
-__copyright__ = 'this file is in the public domain'
+__status__ = "seen"
+
+## gozerbot imports
 
-# gozerbot imports
 from gozerbot.utils.exception import handle_exception
 from gozerbot.monitor import Monitor
 from gozerbot.config import config
 from gozerbot.eventbase import EventBase
 from message import Message
 
+## XMPPmonitor class
+
 class XMPPmonitor(Monitor):
 
     """ monitor jabber output """
 
     def handle(self, bot, event):
-
         """ fire jabber monitor callbacks. """
-
         try:
-            #event.fromm = event['from'] = event.to
             e = Message()
             e.copyin(event)
             e.isreply = True
@@ -34,8 +34,10 @@ class XMPPmonitor(Monitor):
             e.nick = bot.nick
             e.botoutput = True
             Monitor.handle(self, bot, e)
-        except AttributeError:
-            handle_exception()
+        except AttributeError: handle_exception()
+
+## defines
 
-# xmpp monitor
 xmppmonitor = XMPPmonitor('xmppmonitor')
+
+#### BHJTW 22-01-2012
