@@ -2,7 +2,11 @@
 #
 #
 
-# CONSTANTS
+""" define some xmpp constants. """
+
+__status__ = "seen"
+
+## defines
 
 attributes = {}
 subelements = {}
@@ -16,3 +20,5 @@ subelements['presence'] = ['show', 'status', 'priority', 'x']
 
 attributes['iq'] = ['type', 'from', 'to', 'id']
 subelements['iq'] = ['query', 'error']
+
+#### BHJTW 22-01-2012
