@@ -2,19 +2,21 @@
 #
 #
 
-""" Presence. """
+""" XMPP Presence class. """
+
+## gozerbot imports
 
-# gozerbot imports
 from gozerbot.eventbase import EventBase
 from gozerbot.utils.trace import whichmodule
 from gozerbot.utils.log import rlog
-
-# xmpp imports
 from core import XMLDict
 
-# basic imports
+## basic imports
+
 import time
  
+## Presence class
+
 class Presence(EventBase):
 
     def __init__(self, nodedict={}, bot=None):
@@ -25,12 +27,8 @@ class Presence(EventBase):
     def toirc(self):
         """ set ircevent compatible attributes """
         self.cmnd = 'Presence'
-
-        try:
-            self.nick = self.fromm.split('/')[1]
-        except (AttributeError, IndexError):
-            self.nick = ""
-
+        try: self.nick = self.fromm.split('/')[1]
+        except (AttributeError, IndexError): self.nick = ""
         self.jid = self.jid or self.fromm
         self.ruserhost = self.jid
         self.userhost = str(self.jid)
@@ -40,11 +38,8 @@ class Presence(EventBase):
         self.printto = self.channel
         self.origtxt = self.txt
         self.time = time.time()
-        
-        if self.type == 'groupchat':
-            self.groupchat = True
-        else:
-            self.groupchat = False
+        if self.type == 'groupchat': self.groupchat = True
+        else: self.groupchat = False
+        if self.txt: makeargrest(self)
 
-        if self.txt:
-            makeargrest(self)
+#### BHJTW 22-01-2012
