@@ -1,22 +1,30 @@
-# plugs/8b.py
+# gplugs/8b.py
 #
 #
 #
 
 """ eight ball """
 
-__copyright__ = 'this file is in the public domain'
-__revision__ = '$Id: m8b.py 1120 2006-12-30 12:00:00Z deck $'
+__status__ = "seen"
+
+## gozerbot imports
 
 from gozerbot.generic import handle_exception
 from gozerbot.commands import cmnds
 from gozerbot.examples import examples
 from gozerbot.plughelp import plughelp
 from gozerbot.tests import tests
+
+## basic imports
+
 import re, random
 
+## plughelp
+
 plughelp.add('8b', 'Ask the magic 8 ball')
 
+## defines
+
 balltxt=[
     "Signs point to yes.",
     "Yes.",
@@ -40,9 +48,13 @@ balltxt=[
     "Don't count on it."
     ]
 
+## 8b command
+
 def handle_8b(bot, ievent):
     ievent.reply(random.choice(balltxt))
 
 cmnds.add('8b', handle_8b, 'USER')
 examples.add('8b', 'show what the magic 8 ball has to say', '8b')
 tests.add('8b')
+
+#### BHJTW 22-01-2012
