@@ -4,7 +4,8 @@
 
 """ karma plugin """
 
-__copyright__ = 'this file is in the public domain'
+## still needs to be documented
+
 __depending__ = ['fans', 'quote']
 
 from gozerbot.tests import tests
@@ -61,92 +62,6 @@ class WhoKarma(Base):
         self.nick = nick
         self.updown = updown
 
-## UPGRADE PART
-
-def upgrade():
-    teller = 0
-    oldfile = datadir + os.sep + 'old'
-    dbdir = datadir + os.sep + 'db' + os.sep + 'karma.db'
-    if os.path.exists(dbdir):
-        try:
-            from gozerbot.database.db import Db
-            db = Db(dbtype='sqlite')
-            db.connect('db/karma.db')
-            result = db.execute(""" SELECT * FROM karma """)
-            if result:
-                for i in result:
-                    karma.add(i[0], i[1])
-                    teller += 1
-            result = db.execute(""" SELECT * FROM whokarma """)
-            if result:
-                for i in result:
-                    if i[2] == 'up':
-                        karma.setwhoup(i[0], i[1])
-                    else:
-                        karma.setwhodown(i[0], i[1])
-            result = db.execute(""" SELECT * FROM whykarma """)
-            if result:
-                for i in result:
-                    karma.addwhy(*i)
-        except Exception, ex:
-            handle_exception()
-        return teller
-
-    try:
-        from gozerbot.utils.generic import dosed
-        from gozerbot.database.db import Db
-        from gozerbot.compat.karma import Karma
-
-        oldkarma = Karma(oldfile) 
-
-        if not oldkarma:
-            return
-
-        k = oldkarma
-        got = []
-
-        rlog(10, 'karma', 'upgrading karma items')
-        for i,j in k.karma.iteritems():
-            if i in got:
-                continue
-            else:
-                got.append(i)
-                try:
-                    karma.add(i,j)
-                    teller += 1
-                except sa.exc.IntegrityError, ex:
-                    #if 'not unique' in str(ex):
-                    #    continue
-                    raise
-
-        rlog(10, 'karma', 'upgrading reasonup')
-        for i,j in k.reasonup.iteritems():
-            for z in j:
-                karma.addwhy(i, 'up', z)
-
-        rlog(10, 'karma', 'upgrading reasondown')
-        for i,j in k.reasondown.iteritems():
-            for z in j:
-                karma.addwhy(i, 'down', z)
-
-        rlog(10, 'karma', 'upgrading whodown')
-        for i,j in k.whodown.iteritems():
-            for z in j:
-                karma.setwhodown(i, z)
-
-        rlog(10, 'karma', 'upgrading whoup')
-        for i,j in k.whoup.iteritems():
-            for z in j:
-                karma.setwhoup(i, z)
-
-    except Exception, ex:
-        handle_exception()
-        rlog(10, 'karma', 'failed to upgrade: %s' % str(ex))
-        return
-    rlog(10, 'karma', 'upgraded %s karma items' % str(teller))
-
-# END UPGRADE PART
-
 plughelp.add('karma', 'maintain karma of items .. use ++ to raise karma by 1 \
 or use -- to lower by 1 .. reason might be given after a "#"')
 
