@@ -6,7 +6,7 @@
  be provided to set time on a todo item.
 """
 
-__copyright__ = 'this file is in the public domain'
+## still needs to be documented
 
 from gozerbot.generic import strtotime, striptime, getwho, today, lockdec, \
 handle_exception, rlog
@@ -19,7 +19,7 @@ from gozerbot.persist.persist import PlugPersist
 from gozerbot.plughelp import plughelp
 from gozerbot.aliases import aliases
 from gozerbot.config import config
-from gozerplugs.alarm import alarms
+from gplugs.alarm import alarms
 import time, thread, os
 
 from datetime import datetime, timedelta
@@ -69,57 +69,6 @@ if config['GAE']:
        priority = db.IntegerProperty()
 
 
-## UPGRADE PART
-
-def upgrade():
-    rlog(10, 'todo', 'upgrading')
-    teller = 0
-    oldfile = datadir + os.sep + 'old' + os.sep + 'todo'
-    dbdir = datadir + os.sep + 'db' + os.sep + 'todo.db' 
-    if os.path.exists(dbdir):
-        try:
-            from gozerbot.database.db import Db
-            db = Db(dbtype='sqlite')
-            db.connect('db/todo.db')
-            result = db.execute(""" SELECT * FROM todo """)
-            if result:
-                for i in result:
-                    todo.add(i[1], i[5],*i[2:4])
-                    teller += 1
-        except Exception, ex:  
-            handle_exception() 
-        return teller
-    try:
-        from gozerbot.utils.generic import dosed
-        from gozerbot.compat.persist import Persist
-        from gozerbot.compat.todo import Todoitem
-        dosed(oldfile, 's/cgozerbot\.compat/cgozerplugs/')
-        oldpersist = Persist(oldfile) 
-        if not oldpersist or not oldpersist.data:
-            return
-        for name, itemlist in oldpersist.data.iteritems():
-            for item in itemlist:
-                if item.duration == None:
-                    duration = 0
-                else:
-                    duration = item.duration
-                if item.priority == None:
-                    priority = 0
-                else:
-                    priority = item.priority
-                todo.add(name, item.descr, item.time, duration, item.warnsec, priority)
-                teller += 1  
-    except IOError, ex:
-        if 'No such file' in str(ex):
-            rlog(10, 'todo', 'nothing to upgrade')
-    except Exception, ex:
-        rlog(10, 'todo', "can't upgrade .. reason: %s" % str(ex))
-        handle_exception()
-    else:
-        rlog(10, 'todo', "upgraded %s items" % teller)
-
-## END UPGRADE PART
-
 plughelp.add('todo', 'todo lists')
 
 todolock = thread.allocate_lock()
@@ -254,20 +203,6 @@ def size():
     """ return number of todo entries """
     return todo.size()
 
-def handle_todoupgrade(bot, ievent):
-    if todo.size():
-         if '-f' in ievent.optionset:
-             pass
-         else:
-             ievent.reply('there are already todo items in the main database .. not upgrading')
-             ievent.reply('use the -f option to force an upgrade')
-             return
-    ievent.reply('upgrading todo')
-    nritems = upgrade()
-    ievent.reply('%s items upgraded' % nritems)
-
-cmnds.add('todo-upgrade', handle_todoupgrade, 'OPER', options={'-f': ''})
-
 def handle_todo(bot, ievent):
     """ todo [<item>] .. show todo's or set todo item .. a time/date can be \
 given"""
