@@ -1,3 +1,5 @@
+# gplugs/bugtracker.py
+#
 # -*- coding: utf-8 -*-
 # Support for bugtrackers
 # Wijnand 'tehmaze' Modderman - http://tehmaze.com
@@ -16,6 +18,10 @@
 #    will work on all installations, for example on older versions or on bugtrackers
 #    that restyled the complete layout
 
+__status__ = "seen"
+
+## gozerbot imports
+
 from gozerbot.aliases import aliases
 from gozerbot.callbacks import callbacks
 from gozerbot.commands import cmnds
@@ -26,26 +32,31 @@ from gozerbot.persist.pdod import Pdod
 from gozerbot.persist.persistconfig import PersistConfig
 from gozerbot.plughelp import plughelp
 from gozerbot.users import users
-from gozerbot.utils.generic import convertpickle
+
+## basic imports
+
 import copy
 import os
 import re
 import urllib, urllib2
 import xml.dom.minidom
 
+## plughelp
+
 plughelp.add('bugtracker', 'various bug tracker support, define a bugtracker for the channel with bugtracker-set')
 
+## defines
+
 cfg = PersistConfig()
 cfg.define('sep', '..')
 
-class BugTrackerNotFound(Exception):
-    pass
+## exceptions
 
-class BugTrackerNotImplemented(Exception):
-    pass
+class BugTrackerNotFound(Exception): pass
 
-class BugTrackerNotSupported(Exception):
-    pass
+class BugTrackerNotImplemented(Exception): pass
+
+class BugTrackerNotSupported(Exception): pass
 
 class BugTracker:
 
@@ -85,88 +96,70 @@ class BugTracker:
 
     def show_url(self, bugId):
         raise BugTrackerNotImplemented
-        
+
+    ### bug-close command
+
     def handle_close(self, bot, ievent):
-        if len(ievent.args) < 3:
-            ievent.missing('<bug id> <action> <message>')
-            return
+        if len(ievent.args) < 3: ievent.missing('<bug id> <action> <message>') ; return
         try:
-            status = self.close(ievent.args[0], users.getname(ievent.userhost), 
-                ' '.join(ievent.args[2:]), ievent.args[1])
+            status = self.close(ievent.args[0], users.getname(ievent.userhost), ' '.join(ievent.args[2:]), ievent.args[1])
             ievent.reply('ok')
-        except AssertionError, e:
-            ievent.reply('error: %s' % e)
-        except BugTrackerNotImplemented:
-            ievent.reply('error: not implemented in this bug tracker')
-        except BugTrackerNotSupported, e:
-            ievent.reply('error: not supported: %s' % e)
-        except BugTrackerNotFound, e:
-            ievent.reply('error: not found: %s' % e)
+        except AssertionError, e: ievent.reply('error: %s' % e)
+        except BugTrackerNotImplemented: ievent.reply('error: not implemented in this bug tracker')
+        except BugTrackerNotSupported, e: ievent.reply('error: not supported: %s' % e)
+        except BugTrackerNotFound, e: ievent.reply('error: not found: %s' % e)
+
+    ### bug-comments command
 
     def handle_comments(self, bot, ievent):
-        if not ievent.args or not ievent.args[0].isdigit():
-            ievent.missing('<bug id>')
-            return
+        if not ievent.args or not ievent.args[0].isdigit(): ievent.missing('<bug id>') ; return
         try:
             comments = self.comments(ievent.args[0])
-            if comments:
-                ievent.reply('comments: ', comments, dot=' %s ' % cfg.get('sep'), nr=True, nritems=True)
-            else:
-                ievent.reply('no comments found')
-        except AssertionError, e:
-            ievent.reply('error: %s' % e)
-        except BugTrackerNotImplemented:
-            ievent.reply('error: not implemented in this bug tracker')
-        except BugTrackerNotSupported, e:
-            ievent.reply('error: not supported: %s' % e)
-        except BugTrackerNotFound, e:
-            ievent.reply('error: not found: %s' % e)
+            if comments: ievent.reply('comments: ', comments, dot=' %s ' % cfg.get('sep'), nr=True, nritems=True)
+            else: ievent.reply('no comments found')
+        except AssertionError, e: ievent.reply('error: %s' % e)
+        except BugTrackerNotImplemented: ievent.reply('error: not implemented in this bug tracker')
+        except BugTrackerNotSupported, e: ievent.reply('error: not supported: %s' % e)
+        except BugTrackerNotFound, e: ievent.reply('error: not found: %s' % e)
+
+    ## bug-list command
 
     def handle_list(self, bot, ievent):
         try:
             bugs = self.list()
-            if bugs:
-                ievent.reply('open bugs: ', bugs, dot=' %s ' % cfg.get('sep'))
-            else:
-                ievent.reply('no open bugs found!')
-        except BugTrackerNotImplemented:
-            ievent.reply('error: not implemented in this bug tracker')
-        except BugTrackerNotSupported, e:
-            ievent.reply('error: not supported: %s' % e)
-        except BugTrackerNotFound, e:
-            ievent.reply('error: not found: %s' % e)
+            if bugs: ievent.reply('open bugs: ', bugs, dot=' %s ' % cfg.get('sep'))
+            else: ievent.reply('no open bugs found!')
+        except BugTrackerNotImplemented: ievent.reply('error: not implemented in this bug tracker')
+        except BugTrackerNotSupported, e: ievent.reply('error: not supported: %s' % e)
+        except BugTrackerNotFound, e: ievent.reply('error: not found: %s' % e)
+
+    ## bug-show command
 
     def handle_show(self, bot, ievent):
         if len(ievent.args) != 1:
             try:
                 open_url = self.open_url()
                 ievent.missing('<bug id> -- if you were looking to report a bug, please go to %s' % open_url)
-            except BugTrackerNotImplemented:
-                ievent.missing('<bug id>')
+            except BugTrackerNotImplemented: ievent.missing('<bug id>')
             return
         try:
             status = self.show(ievent.args[0])
             result = []
             keys   = status.keys() ; keys.sort()
             for key in keys:
-                if status[key]:
-                    result.append('%s=%s' % (key, status[key]))
+                if status[key]: result.append('%s=%s' % (key, status[key]))
             result.append(self.show_url(ievent.args[0]))
             ievent.reply(result, dot=' %s ' % cfg.get('sep'))
-        except AssertionError, e:
-            ievent.reply('error: %s' % e)
-        except BugTrackerNotImplemented:
-            ievent.reply('error: not implemented in this bug tracker')
-        except BugTrackerNotSupported, e:
-            ievent.reply('error: not supported: %s' % e)
-        except BugTrackerNotFound, e:
-            ievent.reply('error: not found: %s' % e)
+        except AssertionError, e: ievent.reply('error: %s' % e)
+        except BugTrackerNotImplemented: ievent.reply('error: not implemented in this bug tracker')
+        except BugTrackerNotSupported, e: ievent.reply('error: not supported: %s' % e)
+        except BugTrackerNotFound, e: ievent.reply('error: not found: %s' % e)
+
+    ### scan_privmsg callback
 
     def scan_privmsg(self, bot, ievent):
-        if not self.autoshow:
-            return
-        if not self.bugurls:
-            return
+        if not self.autoshow: return
+        if not self.bugurls: return
         for bugurl in self.bugurls:
             test = bugurl.findall(ievent.origtxt)
             if test:
@@ -183,30 +176,29 @@ class BugTracker:
             del nevent
             return
 
+## Bogzilla class
+
 class Bugzilla(BugTracker):
+
+    """ Class for the Bugzilla bugtracker. """
+
     def __init__(self, url, autoshow):
         BugTracker.__init__(self, url, autoshow)
-        self.bugurls = [
-            re.compile(r'%s/show_bug.*id=(\d+)' % self.url)
-            ]
+        self.bugurls = [re.compile(r'%s/show_bug.*id=(\d+)' % self.url)]
 
     def list(self):
         csv = geturl2(self.list_url_summary())
         num = 0
         for line in csv.splitlines():
-            try:
-                num += int(line.split(',')[1])
-            except ValueError:
-                pass
+            try: num += int(line.split(',')[1])
+            except ValueError: pass
         bugs = []
-        if num > 100:
-            bugs.append('showing 100-%d' % num)
+        if num > 100: bugs.append('showing 100-%d' % num)
         csv = geturl2(self.list_url())
         for line in csv.splitlines()[1:]:
             part = line.split(',')
             bugs.append('%s (%s)' % (part[0], part[1].replace('"', '')))
-            if len(bugs) > 100:
-                break
+            if len(bugs) > 100: break
         return bugs        
 
     def list_url(self):
@@ -219,21 +211,16 @@ class Bugzilla(BugTracker):
         assert bugId.isdigit(), "bug id has to be a number"
         bugxml = geturl(self.show_url_xml(bugId))
         bugdom = xml.dom.minidom.parseString(bugxml)
-        try:
-            bugset = bugdom.getElementsByTagName('bug')[0]
-        except:
-            raise BugTrackerNotFound('could not find bug tag')
-        bugget = {'creation_ts': 'created', 'product': 'product', 'component': 'component',
-            'version': 'version', 'bug_status': 'status', 'resolution': 'resolution',
-            'priority': 'priority', 'bug_severity': 'severity', 'reporter': 'reporter',
-            'short_desc': 'description', 'assigned_to': 'assigned to'}
+        try: bugset = bugdom.getElementsByTagName('bug')[0]
+        except: raise BugTrackerNotFound('could not find bug tag')
+        bugget = {'creation_ts': 'created', 'product': 'product', 'component': 'component', 'version': 'version', 'bug_status': 'status', 'resolution': 'resolution',
+            'priority': 'priority', 'bug_severity': 'severity', 'reporter': 'reporter', 'short_desc': 'description', 'assigned_to': 'assigned to'}
         data = {}
         for tag in bugget.keys():
             try:
                 value = bugset.getElementsByTagName(tag)[0].firstChild.nodeValue
                 data[bugget[tag]] = value
-            except:
-                pass
+            except: pass
         return data
 
     def show_url(self, bugId):
@@ -244,7 +231,12 @@ class Bugzilla(BugTracker):
         assert bugId.isdigit(), "bug id has to be a number"
         return '%s/show_bug.cgi?ctype=xml&id=%s' % (self.url, bugId)
 
+## Flyspray class
+
 class Flyspray(BugTracker):
+
+    """ Flyspray handling class. """
+
     def __init__(self, url, autoshow):
         BugTracker.__init__(self, url, autoshow)
         self.bugurls = [
@@ -261,8 +253,7 @@ class Flyspray(BugTracker):
                 try:
                     bugid = entry.getElementsByTagName('id')[0].firstChild.nodeValue.split(':')[2]
                     bugs.append(bugid)
-                except:
-                    pass
+                except: pass
         return bugs
 
     def list_url(self):
@@ -275,8 +266,7 @@ class Flyspray(BugTracker):
         stat = ''
         for line in html.splitlines():
             line = line.strip()
-            if not line:
-                continue
+            if not line: continue
             elif '<td headers="category">' in line:
                 stat = 'category'
             elif '<td headers="status">' in line:
@@ -306,6 +296,8 @@ class Flyspray(BugTracker):
         assert bugId.isdigit(), "bug id has to be a number"
         return '%s/task/%s' % (self.url, bugId)
 
+## GoogleCode class
+
 class GoogleCode(BugTracker):
     def __init__(self, url, autoshow):
         BugTracker.__init__(self, url, autoshow)
@@ -322,8 +314,7 @@ class GoogleCode(BugTracker):
         for line in html.splitlines():
             if '<a href="detail?id' in line and '&amp;' in line:
                 bug = line.split('id=')[1].split('&amp;')[0]
-                if not bug in bugs:
-                    bugs.append(bug)
+                if not bug in bugs: bugs.append(bug)
         return bugs
 
     def list_url(self):
@@ -373,6 +364,8 @@ class GoogleCode(BugTracker):
         assert bugId.isdigit(), "bug id has to be a number"
         return '%s/issues/detail?id=%s' % (self.url.rstrip('/'), bugId)
 
+## Mantis class
+
 class Mantis(BugTracker):
     def __init__(self, url, autoshow):
         BugTracker.__init__(self, url, autoshow)
@@ -430,6 +423,8 @@ class Mantis(BugTracker):
         assert bugId.isdigit(), "bug id has to be a number"
         return '%s/view.php?id=%s' % (self.url.rstrip('/'), bugId)
 
+## Trac class
+
 class Trac(BugTracker):
     def __init__(self, url, autoshow):
         BugTracker.__init__(self, url, autoshow)
@@ -536,6 +531,8 @@ class Trac(BugTracker):
         req.add_header('User-agent', useragent())
         return urllib2.urlopen(req).read()
 
+## BugMananger class
+
 class BugManager(Pdod):
 
     types = {
@@ -549,49 +546,35 @@ class BugManager(Pdod):
         }
 
     def __init__(self):
-        Pdod.__init__(self, os.path.join(datadir + os.sep + 'plugs' + os.sep \
-+ 'bugtracker', 'bugtracker'))
+        Pdod.__init__(self, os.path.join(datadir + os.sep + 'plugs' + os.sep + 'bugtracker', 'bugtracker'))
         self.load()
 
     def add(self, bot, ievent, type, url):
         assert type in self.types.keys(), "unknown bugtracker type, supported: %s" % ', '.join(self.types.keys())
-        if hasattr(bot, 'name'):
-            botname = bot.name
-        else:
-            botname = bot
-        if hasattr(ievent, 'channel'):
-            channel = ievent.channel
-        else:
-            channel = ievent
-        if not self.data.has_key(botname):
-            self.data[botname] = {}
+        if hasattr(bot, 'name'): botname = bot.name
+        else: botname = bot
+        if hasattr(ievent, 'channel'): channel = ievent.channel
+        else: channel = ievent
+        if not self.data.has_key(botname): self.data[botname] = {}
         self.data[bot.name][channel] = [url, type, False]
         self.save()
         self.start(bot, ievent)
 
     def check(self, bot, ievent):
-        if not self.instances.has_key(bot.name):
-            return False
-        if not self.instances[bot.name].has_key(ievent.channel):
-            return False
+        if not self.instances.has_key(bot.name): return False
+        if not self.instances[bot.name].has_key(ievent.channel): return False
         return True
 
     def load(self):
         for bot in self.data.keys():
-            for channel in self.data[bot].keys():
-                self.start(bot, channel)
+            for channel in self.data[bot].keys(): self.start(bot, channel)
                 
     def start(self, bot, ievent):
-        if hasattr(bot, 'name'):
-            botname = bot.name
-        else:
-            botname = bot
-        if hasattr(ievent, 'channel'):
-            channel = ievent.channel
-        else:
-            channel = ievent
-        if not self.instances.has_key(botname):
-            self.instances[botname] = {}
+        if hasattr(bot, 'name'): botname = bot.name
+        else: botname = bot
+        if hasattr(ievent, 'channel'): channel = ievent.channel
+        else: channel = ievent
+        if not self.instances.has_key(botname): self.instances[botname] = {}
         data = self.data[botname][channel]
         if not len(data) == 3:
             data.append(False)
@@ -601,97 +584,68 @@ class BugManager(Pdod):
 
     # "internals"
     def handle_tracker_info(self, bot, ievent):
-        if not self.check(bot, ievent):
-            ievent.reply('no bugtracker active on %s' % ievent.channel)
+        if not self.check(bot, ievent): ievent.reply('no bugtracker active on %s' % ievent.channel)
         else:
             data = self.data[bot.name][ievent.channel]
             ievent.reply('bugtracker type: %s .. url: %s .. autoshow: %s' % (data[1], data[0], str(data[2])))
     
     def handle_tracker_set(self, bot, ievent):
-        if len(ievent.args) != 2:
-            ievent.missing('<type> <url>')
-            return
+        if len(ievent.args) != 2: ievent.missing('<type> <url>') ; return
         try:
             self.add(bot, ievent, ievent.args[0], ievent.args[1])
             ievent.reply('ok')
-        except AssertionError, e:
-            ievent.reply('error: %s' % e) 
+        except AssertionError, e: ievent.reply('error: %s' % e) 
 
     def handle_autoshow(self, bot, ievent):
-        if not self.check(bot, ievent):
-            ievent.reply('no bugtracker configured')
-            return
+        if not self.check(bot, ievent): ievent.reply('no bugtracker configured') ; return
         self.data[bot.name][ievent.channel][2] = not self.data[bot.name][ievent.channel][2]
-        try:
-            self.instances[bot.name][ievent.channel].autoshow = self.data[bot.name][ievent.channel][2]
-        except:
-            pass
+        try: self.instances[bot.name][ievent.channel].autoshow = self.data[bot.name][ievent.channel][2]
+        except: pass
         self.save()
         ievent.reply('autoshow is now %s' % str(self.data[bot.name][ievent.channel][2]))
 
-    # proxies
+    ### proxies
+
     def handle_close(self, bot, ievent):
-        if not self.check(bot, ievent):
-            ievent.reply('no bugtracker configured')
-            return
-        try:
-            self.instances[bot.name][ievent.channel].handle_close(bot, ievent)
-        except Exception, e:
-            ievent.reply('failed to get bug information: %s' % str(e))
+        if not self.check(bot, ievent): ievent.reply('no bugtracker configured') ; return
+        try: self.instances[bot.name][ievent.channel].handle_close(bot, ievent)
+        except Exception, e: ievent.reply('failed to get bug information: %s' % str(e))
 
     def handle_comments(self, bot, ievent):
-        if not self.check(bot, ievent):
-            ievent.reply('no bugtracker configured')
-            return
-        #try:
-	self.instances[bot.name][ievent.channel].handle_comments(bot, ievent)
-        #except Exception, e:
-        #    ievent.reply('failed to get bug information: %s' % str(e))
+        if not self.check(bot, ievent): ievent.reply('no bugtracker configured') ; return
+        try: self.instances[bot.name][ievent.channel].handle_comments(bot, ievent)
+        except Exception, e: ievent.reply('failed to get bug information: %s' % str(e))
     
     def handle_list(self, bot, ievent):
-        if not self.check(bot, ievent):
-            ievent.reply('no bugtracker configured')
-            return
-        self.instances[bot.name][ievent.channel].handle_list(bot, ievent)
-        return
-        try:
-            self.instances[bot.name][ievent.channel].handle_list(bot, ievent)
-        except Exception, e:
-            ievent.reply('failed to get bug information: %s' % str(e))
+        if not self.check(bot, ievent): ievent.reply('no bugtracker configured') ; return
+        try: self.instances[bot.name][ievent.channel].handle_list(bot, ievent)
+        except Exception, e: ievent.reply('failed to get bug information: %s' % str(e))
 
     def handle_open(self, bot, ievent):
-        if not self.check(bot, ievent):
-            ievent.reply('no bugtracker configured')
-            return
-        try:
-            self.instances[bot.name][ievent.channel].handle_open(bot, ievent)
-        except Exception, e:
-            ievent.reply('failed to get bug information: %s' % str(e))
+        if not self.check(bot, ievent): ievent.reply('no bugtracker configured') ; return
+        try: self.instances[bot.name][ievent.channel].handle_open(bot, ievent)
+        except Exception, e: ievent.reply('failed to get bug information: %s' % str(e))
 
     def handle_show(self, bot, ievent):
-        if not self.data.has_key(bot.name):
-            ievent.reply('no bugtracker configured')
-            return False
-        try:
-            self.instances[bot.name][ievent.channel].handle_show(bot, ievent)
-        except Exception, e:
-            ievent.reply('failed to fetch bug information: %s' % str(e))
+        if not self.data.has_key(bot.name): ievent.reply('no bugtracker configured') ; return False
+        try: self.instances[bot.name][ievent.channel].handle_show(bot, ievent)
+        except Exception, e: ievent.reply('failed to fetch bug information: %s' % str(e))
 
     def cb_privmsg(self, bot, ievent):
-        if not self.instances.has_key(bot.name):
-            return 0
-        if not self.instances[bot.name].has_key(ievent.channel):
-            return 0
+        if not self.instances.has_key(bot.name): return 0
+        if not self.instances[bot.name].has_key(ievent.channel): return 0
         self.instances[bot.name][ievent.channel].scan_privmsg(bot, ievent)
 
+## define2
+
 bugtrackers = BugManager()
 
+## init function
+
 def init():
     callbacks.add('PRIVMSG', bugtrackers.cb_privmsg)
 
-def upgrade():
-    convertpickle(datadir + os.sep + 'old' + os.sep + 'bugtracker', \
-datadir + os.sep + 'plugs' + os.sep + 'bugtracker' + os.sep + 'bugtracker')
+## register commands
 
 cmnds.add('bug-autoshow', bugtrackers.handle_autoshow, ['OPER'])
 examples.add('bug-autoshow', 'toggle automatic retrieval of bug information', 'bug-autoshow')
@@ -707,4 +661,5 @@ cmnds.add('bugtracker-info', bugtrackers.handle_tracker_info, ['BUGSOPER', 'OPER
 cmnds.add('bugtracker-set', bugtrackers.handle_tracker_set, ['BUGSOPER', 'OPER'])
 examples.add('bugtracker-set', 'set a bugtracker for the channel', 'bugtracker-set gozerbot http://dev.gozerbot.org')
 aliases.data['bug'] = 'bug-show'
- 
+
+#### BHJTW 22-01-2012
