@@ -1,11 +1,30 @@
+# gplugs/dope.py
+#
+#
+
+""" do the dope dance. """
+
+__status__ = "high"
+
+## gozerbot imports
+
 from gozerbot.tests import tests
 from gozerbot.commands import cmnds
 from gozerbot.examples import examples
 from gozerbot.plughelp import plughelp
-import os, string, random
+
+## basic imports
+
+import os
+import string
+import random
+
+## plughelp
 
 plughelp.add('dope', 'for all the junkies out there')
 
+## defines
+
 joint = '''
 purple haze
 white widow
@@ -55,6 +74,7 @@ bakes a %s cake
 pulls a %s tea
 '''.strip().splitlines()
 
+## joint command
 
 def handle_joint(bot, ievent):
     """ get a joint  """
@@ -64,3 +84,5 @@ def handle_joint(bot, ievent):
 cmnds.add('joint', handle_joint, 'USER')
 examples.add('joint', 'get a joint', 'joint')
 tests.add('joint')
+
+#### BHJTW 22-01-2012
