@@ -2,15 +2,25 @@
 #
 #
 
+""" show some facts. """
+
+## gozerbot imports
+
 from gozerbot.commands import cmnds
 from gozerbot.examples import examples
 from gozerbot.plughelp import plughelp
 from gozerbot.tests import tests
 
+## basic imports
+
 import random
 
+## plughelp
+
 plughelp.add('facts', 'show some facts')
 
+## defines
+
 chucktxt = """
 Crop circles are Chuck Norris' way of telling the world that sometimes corn needs to lie  down.
 Chuck Norris is ten feet tall, weighs two-tons, breathes fire, and could eat a hammer and take a shotgun blast standing.
@@ -717,6 +727,8 @@ chuck = ['booo', ]
 schneier = ['booo', ]
 theo = ['booo', ]
 
+## init function
+
 def init():
     global chuck
     global schneier
@@ -726,29 +738,37 @@ def init():
     theo = theotxt.splitlines()
     return 1
 
+## check command
+
 def handle_chuck(bot, ievent):
     """ get chuck norris fact """
     rand = random.randint(1,len(chuck))
     ievent.reply(chuck[rand-1].strip())
 
+cmnds.add('chuck', handle_chuck, 'USER')
+examples.add('chuck', 'generate chuck norris fact', 'chuck')
+tests.add('chuck')
+
+## scheier command
+
 def handle_schneier(bot, ievent):
     """ get schneier fact """
     rand = random.randint(1,len(schneier))
     ievent.reply(schneier[rand-1].strip())
 
+cmnds.add('schneier', handle_schneier, 'USER')
+examples.add('schneier', 'generate bruce schneier fact', 'schneier')
+tests.add('schneier')
+
+## theo command
+
 def handle_theo(bot, ievent):
     """ get theo """
     rand = random.randint(1,len(theo))
     ievent.reply(theo[rand-1].strip())
 
-cmnds.add('chuck', handle_chuck, 'USER')
-examples.add('chuck', 'generate chuck norris fact', 'chuck')
-tests.add('chuck')
-
-cmnds.add('schneier', handle_schneier, 'USER')
-examples.add('schneier', 'generate bruce schneier fact', 'schneier')
-tests.add('schneier')
-
 cmnds.add('theo', handle_theo, 'USER')
 examples.add('theo', 'generate theo de raadt fact', 'theo')
 tests.add('theo')
+
+#### BHJTW 22-01-2012
