@@ -1,4 +1,4 @@
-# gozerplugs/identi.py
+# gplugs/identi.py
 # 
 # based on the Twitter post plugin
 # (c) Wijnand 'maze' Modderman <http://tehmaze.com>
@@ -8,9 +8,12 @@
 # issues have been reported so maybe the API part will be removed from this
 # plugin at a later stadium.
 
-# IMPORT SECTION
+""" do the identica. """
+
+__status__ = "seen"
+
+## gozerbot imports
 
-import os
 from gozerbot.commands import cmnds
 from gozerbot.datadir import datadir
 from gozerbot.examples import examples
@@ -22,15 +25,135 @@ from gozerbot.plughelp import plughelp
 from gozerbot.tests import tests
 from gozerbot.users import users
 
-# END IMPORT
+## basic imports
+
+import os
+
+## plughelp
 
 plughelp.add('identi', 'do the identi.ca')
 
+## defines
+
 __version__ = '0.2'
 
-#
-# twitter-py stuff
-#
+## identiapi function
+
+def identiapi(**kwargs):
+    api = Api(**kwargs)
+    #api.SetXTwitterHeaders('gozerbot', 'http://gozerbot.org', __version__)
+    return api
+
+class IdentiUser(Pdol):
+    def __init__(self):
+        Pdol.__init__(self, os.path.join(datadir + os.sep + 'plugs' + os.sep + 'identi', 'identi'))
+
+    def add(self, user, username, password):
+        self.data[user] = [username, password]
+        self.save()
+
+    def remove(self, user):
+        if user in self.data:
+            del self.data[user]
+            self.save()
+
+    def size(self):
+        return len(self.data)
+
+    def __contains__(self, user):
+        return user in self.data
+
+## define2
+
+identiuser = IdentiUser()
+
+## size function
+
+def size():
+    return identiuser.size()
+
+## identi command
+
+def handle_identi(bot, ievent):
+    """ send a identi.ca message. """
+    user = users.getname(ievent.userhost)
+    if not user: ievent.reply("can't find user for %s" % ievent.userhost) ; return
+    if not user in identiuser:
+        ievent.reply('you need a identi.ca account for this command, '
+                     'use "!identi-id <username> <password>"'
+                     'first (in a private message!)')
+        return
+    if ievent.inqueue: result = waitforqueue(ievent.inqueue, 30)
+    elif not ievent.rest: ievent.missing('<text>') ; return
+    else: result = [ievent.rest, ]
+    credentials = identiuser.get(user.name)
+    try:
+        api = identiapi(username=credentials[0], password=credentials[1])
+        for txt in result: status = api.PostUpdate(txt[:119])
+        ievent.reply('blurp posted to https://identi.ca/%s ' % (credentials[0],))
+    except (TwitterError, urllib2.HTTPError), e:
+        ievent.reply('identi failed: %s' % (str(e),))
+
+cmnds.add('identi', handle_identi, 'USER')
+examples.add('identi', 'adds a message to your identi.ca account',  'identi.ca just found the https://gozerbot.org project')
+
+## indenti-friends command
+
+def handle_identi_friends(bot, ievent):
+    """ show identi.ca friends. """
+    from gozerbot.users import users
+    user = users.getname(ievent.userhost)
+    if not user: ievent.reply("can't find user for %s" % ievent.userhost) ; return
+    if not user in identiuser:
+        ievent.reply('you need a identi.ca account for this command, '
+                     'use "!identi-id <username> <password>" '
+                     'first (in a private message!)')
+    else:
+        credentials = identiuser.get(ievent.user)
+        try:
+            api = identiapi(username=credentials[0], password=credentials[1])
+            users = api.GetFriends()
+            users = ['%s (%s)' % (u.name, u.screen_name) for u in users]
+            if users: users.sort() ; ievent.reply('your identi.ca friends: ', users, dot=True)
+            else: ievent.reply('poor you, no friends!')
+        except Exception, e: ievent.reply('identi failed: %s' % (str(e),))
+
+cmnds.add('identi-friends', handle_identi_friends, 'USER')
+examples.add('identi-friends', 'shows your identi.ca friends', 'identi-friends')
+
+## identi-get command
+
+def handle_identi_get(bot, ievent):
+    """ get identi messages. """
+    if not ievent.args: ievent.missing('<username>')
+    else:
+        try:
+            api = identiapi()
+            status = api.GetUserTimeline(ievent.args[0])
+            if status: ievent.reply([html_unescape(s.text) for s in status], dot=True)
+            else: ievent.reply('no result')
+        except (TwitterError, urllib2.HTTPError), e: ievent.reply('identi failed: %s' % (str(e),))
+
+cmnds.add('identi-get', handle_identi_get, 'USER')
+examples.add('identi-get', 'gets the identi messages for a user', 'identi-get tehmaze')
+
+## indeti-id command
+
+def handle_identi_id(bot, ievent):
+    """ set identi.ca id. """
+    user = users.getname(ievent.userhost)
+    if not user: ievent.reply("can't find user for %s" % ievent.userhost) ; return
+    if ievent.channel[0] in '#!&': ievent.reply('%s: use a private message!' % (ievent.nick,)) ; return
+    elif len(ievent.args) != 2: ievent.reply('identi-id <username> <password>')
+    else:
+        identiuser.add(user.name, ievent.args[0], ievent.args[1])
+        ievent.reply('ok')
+
+cmnds.add('identi-id', handle_identi_id, 'USER')
+examples.add('identi-id', 'adds your identi.ca account', 'identi-id example secret')
+
+## twitter-py stuff
+
 # Twitter API
 # (c) DeWitt Clinton <dewitt@google.com>
 # Apache License 2.0
@@ -1605,151 +1728,6 @@ class _FileCache(object):
   def _GetPrefix(self,hashed_key):
     return os.path.sep.join(hashed_key[0:_FileCache.DEPTH])
 
-#
-# gozerbot stuff
-#
 
-def identiapi(**kwargs):
-    api = Api(**kwargs)
-    #api.SetXTwitterHeaders('gozerbot', 'http://gozerbot.org', __version__)
-    return api
+#### BHJTW 22-01-2012
 
-class IdentiUser(Pdol):
-    def __init__(self):
-        Pdol.__init__(self, os.path.join(datadir + os.sep + 'plugs' + \
-os.sep + 'identi', 'identi'))
-
-    def add(self, user, username, password):
-        self.data[user] = [username, password]
-        self.save()
-
-    def remove(self, user):
-        if user in self.data:
-            del self.data[user]
-            self.save()
-
-    def size(self):
-        return len(self.data)
-
-    def __contains__(self, user):
-        return user in self.data
-
-# VARS SECTION
-
-identiuser = IdentiUser()
-
-# END VARS
-
-def upgrade():
-    pass
-
-def size():
-    return identiuser.size()
-
-def handle_identi(bot, ievent):
-
-    """ send a identi.ca message. """
-
-    user = users.getname(ievent.userhost)
-
-    if not user:
-        ievent.reply("can't find user for %s" % ievent.userhost)
-        return
-
-    if not user in identiuser:
-        ievent.reply('you need a identi.ca account for this command, '
-                     'use "!identi-id <username> <password>"'
-                     'first (in a private message!)')
-        return
-    if ievent.inqueue:
-        result = waitforqueue(ievent.inqueue, 30)
-    elif not ievent.rest:
-        ievent.missing('<text>')
-        return
-    else:
-        result = [ievent.rest, ]
-    credentials = identiuser.get(user.name)
-    try:
-        api = identiapi(username=credentials[0], password=credentials[1])
-        for txt in result:
-            status = api.PostUpdate(txt[:119])
-        ievent.reply('blurp posted to https://identi.ca/%s ' % (credentials[0],))
-    except (TwitterError, urllib2.HTTPError), e:
-        ievent.reply('identi failed: %s' % (str(e),))
-
-cmnds.add('identi', handle_identi, 'USER')
-examples.add('identi', 'adds a message to your identi.ca account', 
-    'identi.ca just found the https://gozerbot.org project')
-
-def handle_identi_friends(bot, ievent):
-
-    """ show identi.ca friends. """
-
-    user = users.getname(ievent.userhost)
-
-    if not user:
-        ievent.reply("can't find user for %s" % ievent.userhost)
-        return
-
-    if not user in identiuser:
-        ievent.reply('you need a identi.ca account for this command, '
-                     'use "!identi-id <username> <password>" '
-                     'first (in a private message!)')
-    else:
-        credentials = identiuser.get(ievent.user)
-        try:
-            api = identiapi(username=credentials[0], password=credentials[1])
-            users = api.GetFriends()
-            users = ['%s (%s)' % (u.name, u.screen_name) for u in users]
-            if users:
-                users.sort()
-                ievent.reply('your identi.ca friends: ', users, dot=True)
-            else:
-                ievent.reply('poor you, no friends!')
-        except Exception, e:
-            ievent.reply('identi failed: %s' % (str(e),))
-
-cmnds.add('identi-friends', handle_identi_friends, 'USER')
-examples.add('identi-friends', 'shows your identi.ca friends', 'identi-friends')
-
-def handle_identi_get(bot, ievent):
-
-    """ get identi messages. """
-
-    if not ievent.args:
-        ievent.missing('<username>')
-    else:
-        try:
-            api = identiapi()
-            status = api.GetUserTimeline(ievent.args[0])
-            if status:
-                ievent.reply([html_unescape(s.text) for s in status], dot=True)
-            else:
-                ievent.reply('no result')
-        except (TwitterError, urllib2.HTTPError), e:
-            ievent.reply('identi failed: %s' % (str(e),))
-
-cmnds.add('identi-get', handle_identi_get, 'USER')
-examples.add('identi-get', 'gets the identi messages for a user', 'identi-get tehmaze')
-
-def handle_identi_id(bot, ievent):
-
-    """ set identi.ca id. """
-
-    user = users.getname(ievent.userhost)
-
-    if not user:
-        ievent.reply("can't find user for %s" % ievent.userhost)
-        return
-
-    if ievent.channel[0] in '#!&':
-        ievent.reply('%s: use a private message!' % (ievent.nick,))
-        return
-    elif len(ievent.args) != 2:
-        ievent.reply('identi-id <username> <password>')
-    else:
-        identiuser.add(user.name, ievent.args[0], ievent.args[1])
-        ievent.reply('ok')
-
-cmnds.add('identi-id', handle_identi_id, 'USER')
-examples.add('identi-id', 'adds your identi.ca account', 'identi-id example secret')
