@@ -4,7 +4,9 @@
 
 """ provide todo related commands """
 
-__copyright__ = 'this file is in the public domain'
+__status__ = "seen"
+
+## gozerbot imports
 
 from gozerbot.generic import strtotime, striptime, getwho, today, lockdec
 from gozerbot.commands import cmnds
@@ -16,14 +18,24 @@ from gozerbot.plughelp import plughelp
 from gozerbot.aliases import aliases
 from gozerbot.config import config
 from gplugs.alarm import alarms
-import time, thread, os
 
-plughelp.add('todo', 'manage todo lists .. by user or by channel .. a \
-time/data string can be provided.')
+## basic imports
+
+import time
+import thread
+import os
+
+## plughelp
+
+plughelp.add('todo', 'manage todo lists .. by user or by channel .. a time/data string can be provided.')
+
+## locks
 
 todolock = thread.allocate_lock()
 locked = lockdec(todolock)
 
+## Todoitem class
+
 class Todoitem:
 
     """ a todo item """
@@ -39,9 +51,7 @@ priority=None, num=0):
         self.num = num
 
     def __str__(self):
-        return "name: %s num: %d time: %s duration: %s warnsec: %s \
-description: %s priority: %s" % (self.name, self.num, \
-time.ctime(self.time), self.duration, self.warnsec, self.descr, self.priority)
+        return "name: %s num: %d time: %s duration: %s warnsec: %s description: %s priority: %s" % (self.name, self.num, time.ctime(self.time), self.duration, self.warnsec, self.descr, self.priority)
 
 class Todolist:
 
@@ -74,127 +84,7 @@ class Todolist:
     def __str__(self):
         return str(self.data)
 
-
-class Todo(Persist):
-
-    """ Todoos """
-
-    @locked
-    def __init__(self, filename):
-        Persist.__init__(self, filename)
-        if not self.data:
-            return
-        for key in self.data.keys():
-            todoos = self.data[key]
-            for (k, v) in todoos.data.items():
-                v.num = k
-            newd = Todolist()
-            for i in todoos:
-                newd.append(i)
-            self.data[key] = newd
-
-    def size(self):
-        """ return number of todo entries """
-        return len(self.data)
-
-    def get(self, name):
-        """ get todoos of <name> """
-        if self.data.has_key(name):
-            return self.data[name]
-
-    @locked
-    def add(self, name, txt, ttime, warnsec=0):
-        """ add a todo """
-        name = name.lower()
-        if not self.data.has_key(name):
-            self.data[name] = Todolist()
-        self.data[name].append(Todoitem(name, txt.strip(), ttime, \
-warnsec=0-warnsec))
-        self.save()
-        return len(self.data[name])
-
-    @locked
-    def addnosave(self, name, txt, ttime):
-        """ add but don't save """
-        name = name.lower()
-        if not self.data.has_key(name):
-            self.data[name] = Todolist()
-        self.data[name].append(Todoitem(name, txt, ttime))
-
-
-    @locked
-    def reset(self, name):
-        name = name.lower()
-        if self.data.has_key(name):
-           self.data[name] = Todolist()
-        self.save()
-
-    @locked
-    def delete(self, name, nr):
-        """ delete todo item """
-        if not self.data.has_key(name):
-            return 0
-        todoos = self.data[name]
-        try:
-            if todoos[nr].warnsec:
-                alarmnr = 0 - todoos[nr].warnsec
-                if alarmnr > 0:
-                    alarms.delete(alarmnr)
-            del todoos[nr]
-        except KeyError:
-            return 0
-        self.save()
-        return 1
-
-    def toolate(self, name):
-        """ show if there are any time related todoos that are too late """
-        now = time.time()
-        teller = 0
-        for i in self.data[name]:
-            if i.time < now:
-                teller += 1
-        return teller
-
-    def timetodo(self, name):
-        """ show todoos with time field set """
-        result = []
-        if not self.data.has_key(name):
-            return result
-        for i in self.data[name]:
-            if i.time:
-                result.append(i)
-        return result
-
-    def withintime(self, name, time1, time2):
-        """ show todoos within time frame """
-        result = []
-        if not self.data.has_key(name):
-            return result
-        for i in self.data[name]:
-            if i.time >= time1 and i.time < time2:
-                result.append(i)
-        return result
-
-    @locked
-    def setprio(self, who, itemnr, prio):
-        """ set priority of todo item """
-        try:
-            todoitems = self.get(who)
-            todoitems[itemnr].priority = prio
-            self.save()
-            return 1
-        except (KeyError, TypeError):
-            pass
-
-    def settime(self, who, itemnr, ttime):
-        """ set time of todo item """
-        try:
-            todoitems = self.get(who)
-            todoitems[itemnr].time = ttime
-            self.save()
-            return 1
-        except (KeyError, TypeError):
-            pass
+## TodoDb command
 
 class TodoDb(object):
 
@@ -212,8 +102,7 @@ class TodoDb(object):
     def get(self, name):
         """ get todo list of <name> """
         name = name.lower()
-        result = db.execute(""" SELECT * FROM todo WHERE name = %s ORDER BY \
-priority DESC, indx ASC """, name)
+        result = db.execute(""" SELECT * FROM todo WHERE name = %s ORDER BY priority DESC, indx ASC """, name)
         res = []
         if result:
             for i in result:
@@ -234,26 +123,22 @@ priority DESC, indx ASC """, name)
 
     def setprio(self, who, todonr, prio):
         """ set priority of todonr """
-        result = db.execute(""" UPDATE todo SET priority = %s WHERE indx \
-= %s """, (prio, todonr))
+        result = db.execute(""" UPDATE todo SET priority = %s WHERE indx = %s """, (prio, todonr))
         return result
 
     def getprio(self, who, todonr):
         """ get priority of todonr """
-        result = db.execute(""" SELECT name, priority FROM todo WHERE \
-indx = %s """, todonr)
+        result = db.execute(""" SELECT name, priority FROM todo WHERE indx = %s """, todonr)
         return result
 
     def getwarnsec(self, todonr):
         """ get priority of todonr """
-        result = db.execute(""" SELECT warnsec FROM todo WHERE \
-indx = %s """, todonr)
+        result = db.execute(""" SELECT warnsec FROM todo WHERE indx = %s """, todonr)
         return result
 
     def settime(self, who, todonr, ttime):
         """ set time of todonr """
-        result = db.execute(""" UPDATE todo SET time = %s WHERE indx \
-= %s """, (ttime, todonr))
+        result = db.execute(""" UPDATE todo SET time = %s WHERE indx = %s """, (ttime, todonr))
         return result
 
     def add(self, name, txt, ttime, alarmnr=None):
@@ -262,15 +147,12 @@ indx = %s """, todonr)
         txt = txt.strip()
         if ttime:
             if not alarmnr:
-                result = db.execute(""" INSERT INTO todo(name, time, \
-descr) VALUES (%s, %s, %s) """, (name, ttime, txt))
+                result = db.execute(""" INSERT INTO todo(name, time, descr) VALUES (%s, %s, %s) """, (name, ttime, txt))
             else:
-                result = db.execute(""" INSERT INTO todo(name, time, \
-descr, warnsec) VALUES (%s, %s, %s, %s) """, (name, ttime, txt, 0-alarmnr))
+                result = db.execute(""" INSERT INTO todo(name, time, descr, warnsec) VALUES (%s, %s, %s, %s) """, (name, ttime, txt, 0-alarmnr))
 
         else:
-            result = db.execute(""" INSERT INTO todo(name, descr) \
-VALUES (%s, %s) """, (name, txt))
+            result = db.execute(""" INSERT INTO todo(name, descr) VALUES (%s, %s) """, (name, txt))
         return result
 
     def delete(self, name, indexnr):
@@ -284,16 +166,14 @@ VALUES (%s, %s) """, (name, txt))
                     alarms.delete(alarmnr)
         except (IndexError, TypeError):
             pass
-        result = db.execute(""" DELETE FROM todo WHERE name = %s AND \
-indx = %s """, (name, indexnr))
+        result = db.execute(""" DELETE FROM todo WHERE name = %s AND indx = %s """, (name, indexnr))
         return result
 
     def toolate(self, name):
         """ show if there are any time related todoos that are too late """
         name = name.lower()
         now = time.time()
-        result = db.execute(""" SELECT * FROM todo WHERE name = %s AND \
-time < %s """, (name, now))
+        result = db.execute(""" SELECT * FROM todo WHERE name = %s AND time < %s """, (name, now))
         res = []
         if result:
             for i in result:
@@ -304,8 +184,7 @@ time < %s """, (name, now))
     def withintime(self, name, time1, time2):
         """ show todo list within time frame """
         name = name.lower()
-        result = db.execute(""" SELECT * FROM todo WHERE name = %s AND \
-time > %s AND time < %s """, (name, time1, time2))
+        result = db.execute(""" SELECT * FROM todo WHERE name = %s AND time > %s AND time < %s """, (name, time1, time2))
         res = []
         if result:
             for i in result:
@@ -316,8 +195,7 @@ time > %s AND time < %s """, (name, time1, time2))
     def timetodo(self, name):
         name = name.lower()
         now = time.time()
-        result = db.execute(""" SELECT * FROM todo WHERE time AND name = %s \
-""", name)
+        result = db.execute(""" SELECT * FROM todo WHERE time AND name = %s """, name)
         res = []
         if result:
             for i in result:
@@ -331,21 +209,20 @@ time > %s AND time < %s """, (name, time1, time2))
         result = db.execute(""" DELETE FROM todo WHERE name = %s """, (name, ))
         return result
 
-if not config['nodb']:
-    from gozerbot.database.db import db
-    todo = TodoDb()
-else:
-    todo = Todo(datadir + os.sep + 'todo')
-    if not todo.data:
-        todo.data = {}
+
+from gozerbot.database.db import db
+todo = TodoDb()
+
+## size function
 
 def size():
     """ return number of todo entries """
     return todo.size()
 
+## todo command
+
 def handle_todo(bot, ievent):
-    """ todo [<item>] .. show todo's or set todo item .. a time/date can be \
-given"""
+    """ todo [<item>] .. show todo's or set todo item .. a time/date can be given """
     if len(ievent.args) > 0:
         handle_todo2(bot, ievent)
         return
@@ -377,8 +254,9 @@ def handle_todo2(bot, ievent):
     ievent.reply('todo item %s added' % nr)
 
 cmnds.add('todo', handle_todo, 'USER')
-examples.add('todo', 'todo [<item>] .. show todo items or add a todo item', \
-'1) todo 2) todo program the bot 3) todo 22:00 sleep')
+examples.add('todo', 'todo [<item>] .. show todo items or add a todo item', '1) todo 2) todo program the bot 3) todo 22:00 sleep')
+
+## done command
 
 def handle_tododone(bot, ievent):
     """ todo-done <listofnrs> .. remove todo items """
@@ -404,10 +282,11 @@ def handle_tododone(bot, ievent):
         ievent.reply('%s items deleted' % nrdone)
 
 cmnds.add('todo-done', handle_tododone, 'USER')
-examples.add('todo-done', 'todo-done <listofnrs> .. remove items from \
-todo list', '1) todo-done 1 2) todo-done 3 5 8')
+examples.add('todo-done', 'todo-done <listofnrs> .. remove items from todo list', '1) todo-done 1 2) todo-done 3 5 8')
 aliases.data['done'] = 'todo-done'
 
+## todo-chan command
+
 def handle_chantodo(bot, ievent):
     """ todo-chan [<item>] .. show channel todo's or set todo item for \
 channel"""
@@ -433,10 +312,11 @@ def handle_chantodo2(bot, ievent):
     ievent.reply('todo item %s added' % nr)
 
 cmnds.add('todo-chan', handle_chantodo, 'USER')
-examples.add('todo-chan', 'todo-chan [<item>] .. add channel todo', \
-'todo-chan fix bla')
+examples.add('todo-chan', 'todo-chan [<item>] .. add channel todo', 'todo-chan fix bla')
 aliases.data['chantodo'] = 'todo-chan'
 
+## todo-chandone command
+
 def handle_todochandone(bot, ievent):
     """ todo-chandone <listofnrs> .. remove channel todo item """
     if not ievent.rest:
@@ -461,10 +341,11 @@ def handle_todochandone(bot, ievent):
         ievent.reply('%s items deleted' % nrdone)
 
 cmnds.add('todo-chandone', handle_todochandone, 'USER')
-examples.add('todo-chandone', 'todo-chandone <listofnrs> .. remove item \
-from channel todo list', 'todo-chandone 2')
+examples.add('todo-chandone', 'todo-chandone <listofnrs> .. remove item from channel todo list', 'todo-chandone 2')
 aliases.data['chandone'] = 'todo-chandone'
 
+## todo-set command
+
 def handle_settodo(bot, ievent):
     """ todo-set <name> <txt> .. add a todo to another user's todo list"""
     try:
@@ -486,8 +367,7 @@ def handle_settodo(bot, ievent):
         return
     name = users.getname(ievent.userhost)
     if not users.permitted(userhost, name, 'todo'):
-        ievent.reply("%s doesn't permit todo sharing for %s " % \
-(who, name))
+        ievent.reply("%s doesn't permit todo sharing for %s " % (who, name))
         return
     what = "%s: %s" % (ievent.nick, what)
     ttime = strtotime(what)
@@ -502,8 +382,9 @@ def handle_settodo(bot, ievent):
     ievent.reply('todo item %s added' % nr)
 
 cmnds.add('todo-set', handle_settodo, 'USER')
-examples.add('todo-set', 'todo-set <nick> <txt> .. set todo item of \
-<nick>', 'todo-set dunker bot proggen')
+examples.add('todo-set', 'todo-set <nick> <txt> .. set todo item of <nick>', 'todo-set dunker bot proggen')
+
+## todo-get command
 
 def handle_gettodo(bot, ievent):
     """ todo-get <nick> .. get todo of another user """
@@ -528,8 +409,9 @@ def handle_gettodo(bot, ievent):
     saytodo(bot, ievent, todoos)
 
 cmnds.add('todo-get', handle_gettodo, ['USER', 'WEB'])
-examples.add('todo-get', 'todo-get <nick> .. get the todo list of \
-<nick>', 'todo-get dunker')
+examples.add('todo-get', 'todo-get <nick> .. get the todo list of <nick>', 'todo-get dunker')
+
+## todo-time command
 
 def handle_todotime(bot, ievent):
     """ todo-time .. show time related todoos """
@@ -538,10 +420,11 @@ def handle_todotime(bot, ievent):
     saytodo(bot, ievent, todoos)
 
 cmnds.add('todo-time', handle_todotime, 'USER')
-examples.add('todo-time', 'todo-time .. show todo items with time fields', \
-'todo-time')
+examples.add('todo-time', 'todo-time .. show todo items with time fields', 'todo-time')
 aliases.data['tt'] = 'todo-time'
 
+## todo-week command
+
 def handle_todoweek(bot, ievent):
     """ todo-week .. show time related todo items for this week """
     name = users.getname(ievent.userhost)
@@ -551,6 +434,8 @@ def handle_todoweek(bot, ievent):
 cmnds.add('todo-week', handle_todoweek, 'USER')
 examples.add('todo-week', 'todo-week .. todo items for this week', 'todo-week')
 
+## today command
+
 def handle_today(bot, ievent):
     """ todo-today .. show time related todo items for today """
     name = users.getname(ievent.userhost)
@@ -561,6 +446,8 @@ cmnds.add('todo-today', handle_today, 'USER')
 examples.add('todo-today', 'todo-today .. todo items for today', 'todo-today')
 aliases.data['today'] = 'todo-today'
 
+## tomorrow command
+
 def handle_tomorrow(bot, ievent):
     """ todo-tomorrow .. show time related todo items for tomorrow """
     username = users.getname(ievent.userhost)
@@ -569,8 +456,7 @@ def handle_tomorrow(bot, ievent):
         ttime = strtotime(what)
         if ttime != None:
             if ttime < today() or ttime > today() + 24*60*60:
-                ievent.reply("%s is not tomorrow" % \
-time.ctime(ttime + 24*60*60))
+                ievent.reply("%s is not tomorrow" % time.ctime(ttime + 24*60*60))
                 return
             ttime += 24*60*60
             ievent.reply('time detected ' + time.ctime(ttime))
@@ -584,10 +470,11 @@ time.ctime(ttime + 24*60*60))
     saytodo(bot, ievent, todoos)
 
 cmnds.add('todo-tomorrow', handle_tomorrow, 'USER')
-examples.add('todo-tomorrow', 'todo-tomorrow .. todo items for tomorrow', \
-'todo-tomorrow')
+examples.add('todo-tomorrow', 'todo-tomorrow .. todo items for tomorrow', 'todo-tomorrow')
 aliases.data['tomorrow'] = 'todo-tomorrow'
 
+## todo-setprio command
+
 def handle_setpriority(bot, ievent):
     """ todo-setprio [<channel|name>] <itemnr> <prio> .. show priority \
         on todo item """
@@ -613,14 +500,13 @@ def handle_setpriority(bot, ievent):
     ievent.reply('priority set')
 
 cmnds.add('todo-setprio', handle_setpriority, 'USER')
-examples.add('todo-setprio', 'todo-setprio [<channel|name>] <itemnr> <prio> \
-.. set todo priority', '1) todo-setprio #dunkbots 2 5 2) todo-setprio owner \
-3 10 3) todo-setprio 2 10')
+examples.add('todo-setprio', 'todo-setprio [<channel|name>] <itemnr> <prio> .. set todo priority', '1) todo-setprio #dunkbots 2 5 2) todo-setprio owner 3 10 3) todo-setprio 2 10')
 aliases.data['setprio'] = 'todo-setprio'
 
+## todo-settime command
+
 def handle_todosettime(bot, ievent):
-    """ todo-settime [<channel|name>] <itemnr> <timestring> .. set time \
-        on todo item """
+    """ todo-settime [<channel|name>] <itemnr> <timestring> .. set time on todo item """
     ttime = strtotime(ievent.txt)
     if ttime == None:
         ievent.reply("can't detect time")
@@ -647,9 +533,9 @@ def handle_todosettime(bot, ievent):
     ievent.reply('time of todo %s set to %s' % (itemnr, time.ctime(ttime)))
 
 cmnds.add('todo-settime', handle_todosettime, 'USER')
-examples.add('todo-settime', 'todo-settime [<channel|name>] <itemnr> \
-<timestring> .. set todo time', '1) todo-settime #dunkbots 2 13:00 2) \
-todo-settime owner 3 2-2-2010 3) todo-settime 2 22:00')
+examples.add('todo-settime', 'todo-settime [<channel|name>] <itemnr> <timestring> .. set todo time', '1) todo-settime #dunkbots 2 13:00 2) todo-settime owner 3 2-2-2010 3) todo-settime 2 22:00')
+
+## todo-getprio command
 
 def handle_getpriority(bot, ievent):
     """ todo-getprio <[channel|name]> <itemnr> .. get priority of todo \
@@ -681,10 +567,11 @@ def handle_getpriority(bot, ievent):
     ievent.reply('priority is %s' % prio)
 
 cmnds.add('todo-getprio', handle_getpriority, 'USER')
-examples.add('todo-getprio', 'todo-getprio [<channel|name>] <itemnr> .. get \
-todo priority', '1) todo-getprio #dunkbots 5 2) todo-getprio 3')
+examples.add('todo-getprio', 'todo-getprio [<channel|name>] <itemnr> .. get todo priority', '1) todo-getprio #dunkbots 5 2) todo-getprio 3')
 aliases.data['prio'] = 'todo-getprio'
 
+## saytodo function
+
 def saytodo(bot, ievent, todoos):
     """ output todo items of <name> """
     result = []
@@ -706,3 +593,5 @@ def saytodo(bot, ievent, todoos):
         result.append(res.strip())
     if result:
         ievent.reply("todolist of %s: " % ievent.nick, result, nritems=True)
+
+#### BHJTW 23-01-2012
