@@ -4,7 +4,9 @@
 
 """ users related commands """
 
-__copyright__ = 'this file is in the public domain'
+__status__ = "seen"
+
+## gozerbot imports
 
 from gozerbot.generic import getwho, stripident
 from gozerbot.users import users
@@ -13,8 +15,12 @@ from gozerbot.examples import examples
 from gozerbot.aliases import aliases, aliasdel
 from gozerbot.plughelp import plughelp
 
+## plughelp
+
 plughelp.add('user', 'manage users')
 
+## user-whoami command
+
 def handle_whoami(bot, ievent):
     """ user-whoami .. get your username """
     ievent.reply('%s' % users.getname(ievent.userhost))
@@ -23,6 +29,8 @@ cmnds.add('user-whoami', handle_whoami, 'USER')
 examples.add('user-whoami', 'get your username', 'user-whoami')
 aliases.data['whoami'] = 'user-whoami'
 
+## user-meet command
+
 def handle_meet(bot, ievent):
     """ user-meet <nick> .. introduce a new user to the bot """
     try:
@@ -39,8 +47,7 @@ def handle_meet(bot, ievent):
         return
     username = users.getname(userhost)
     if username:
-        ievent.reply('we already have a user with userhost %s (%s)' % \
-(userhost, username))
+        ievent.reply('we already have a user with userhost %s (%s)' % (userhost, username))
         return
     result = 0
     try:
@@ -54,10 +61,11 @@ def handle_meet(bot, ievent):
         ievent.reply('add failed')
 
 cmnds.add('user-meet', handle_meet, ['OPER', 'MEET'])
-examples.add('user-meet', 'user-meet <nick> .. introduce <nick> to the \
-bot', 'user-meet dunker')
+examples.add('user-meet', 'user-meet <nick> .. introduce <nick> to the bot', 'user-meet dunker')
 aliases.data['meet'] = 'user-meet'
 
+## user-add command
+
 def handle_adduser(bot, ievent):
     """ user-aadd <name> <userhost> .. introduce a new user to the bot """
     try:
@@ -67,8 +75,7 @@ def handle_adduser(bot, ievent):
         return
     username = users.getname(userhost)
     if username:
-        ievent.reply('we already have a user with userhost %s (%s)' % \
-(userhost, username))
+        ievent.reply('we already have a user with userhost %s (%s)' % (userhost, username))
         return
     result = 0
     try:
@@ -82,23 +89,21 @@ def handle_adduser(bot, ievent):
         ievent.reply('add failed')
 
 cmnds.add('user-add', handle_adduser, 'OPER')
-examples.add('user-add', 'user-add <name> <userhost> .. add <name> with \
-<userhost> to the bot', 'user-add dunker bart@localhost')
+examples.add('user-add', 'user-add <name> <userhost> .. add <name> with <userhost> to the bot', 'user-add dunker bart@localhost')
+
+## user-merge command
 
 def handle_merge(bot, ievent):
-    """ user-merge <name> <nick> .. merge the userhost into a already \
-        existing user """
+    """ user-merge <name> <nick> .. merge the userhost into a already existing user """
     if len(ievent.args) != 2:
         ievent.missing('<name> <nick>')
         return  
     name, nick = ievent.args
     name = name.lower()
-    if users.gotperm(name, 'OPER') and not users.allowed(ievent.userhost, \
-'OPER'):
+    if users.gotperm(name, 'OPER') and not users.allowed(ievent.userhost, 'OPER'):
         ievent.reply("only OPER perm can merge with OPER user")
         return
-    if name == 'owner' and not bot.ownercheck(ievent, "can merge with owner \
-user"):
+    if name == 'owner' and not bot.ownercheck(ievent, "can merge with owner user"):
          return 
     if not users.exist(name):
         ievent.reply("we have no user %s" % name)
@@ -109,8 +114,7 @@ user"):
         return
     username = users.getname(userhost)
     if username:
-        ievent.reply('we already have a user with userhost %s (%s)' % \
-(userhost, username))
+        ievent.reply('we already have a user with userhost %s (%s)' % (userhost, username))
         return
     result = 0
     try:
@@ -124,10 +128,11 @@ user"):
         ievent.reply('merge failed')
 
 cmnds.add('user-merge', handle_merge, ['OPER', 'MEET'])
-examples.add('user-merge', 'user-merge <name> <nick> .. merge record with \
-<name> with userhost from <nick>', 'merge bart dunker')
+examples.add('user-merge', 'user-merge <name> <nick> .. merge record with <name> with userhost from <nick>', 'merge bart dunker')
 aliases.data['merge'] = 'user-merge'
 
+## user-del command
+
 def handle_delete(bot, ievent):
     """ user-del <name> .. remove user """
     if len(ievent.args) == 0:
@@ -149,10 +154,11 @@ def handle_delete(bot, ievent):
         ievent.reply('delete of %s failed' % name)
 
 cmnds.add('user-del', handle_delete, 'OPER')
-examples.add('user-del', 'user-del <name> .. delete user with <username>' , \
-'user-del dunker')
+examples.add('user-del', 'user-del <name> .. delete user with <username>' , 'user-del dunker')
 aliases.data['delete'] = 'user-del'
 
+## user-scan command
+
 def handle_userscan(bot, ievent):
     """ user-scan <txt> .. scan for user """
     try:
@@ -173,10 +179,11 @@ def handle_userscan(bot, ievent):
         return
 
 cmnds.add('user-scan', handle_userscan, 'OPER')
-examples.add('user-scan', 'user-scan <txt> .. search database for matching \
-usernames', 'user-scan dunk')
+examples.add('user-scan', 'user-scan <txt> .. search database for matching usernames', 'user-scan dunk')
 aliases.data['us'] = 'user-scan'
 
+## user-names command
+
 def handle_names(bot, ievent):
     """ user-names .. show registered users """
     ievent.reply("usernames: ", users.names(), dot=True)
@@ -185,15 +192,18 @@ cmnds.add('user-names', handle_names, 'OPER')
 examples.add('user-names', 'show names of registered users', 'user-names')
 aliases.data['names'] = 'user-names'
 
+## user-name command
+
 def handle_name(bot, ievent):
     """ user-name .. show name of user giving the command """
     ievent.reply('your name is %s' % users.getname(ievent.userhost))
 
 cmnds.add('user-name', handle_name, 'USER')
-examples.add('user-name', 'show name of user giving the commands', \
-'user-name')
+examples.add('user-name', 'show name of user giving the commands', 'user-name')
 aliases.data['name'] = 'user-name'
 
+## user-getname command
+
 def handle_getname(bot, ievent):
     """ user-getname <nick> .. fetch name of nick """
     try:
@@ -212,11 +222,12 @@ def handle_getname(bot, ievent):
     ievent.reply(name)
 
 cmnds.add('user-getname', handle_getname, 'USER')
-examples.add('user-getname', 'user-getname <nick> .. get the name of \
-<nick>', 'user-getname dunker')
+examples.add('user-getname', 'user-getname <nick> .. get the name of <nick>', 'user-getname dunker')
 aliases.data['gn'] = 'user-getname'
 aliases.data['getname'] = 'user-getname'
 
+## user-addperm command
+
 def handle_addperm(bot, ievent):
     """ user-addperm <name> <perm> .. add permission """
     if len(ievent.args) != 2:
@@ -233,8 +244,7 @@ def handle_addperm(bot, ievent):
         ievent.reply('%s already has permission %s' % (name, perm))
         return         
     try:
-        result = users.db.execute(""" INSERT INTO perms(name, perm) \
-values(%s,%s) """, (name, perm))
+        result = users.db.execute(""" INSERT INTO perms(name, perm) values(%s,%s) """, (name, perm))
     except Exception, ex:
         ievent.reply("ERROR: %s" % str(ex))
         return
@@ -244,11 +254,12 @@ values(%s,%s) """, (name, perm))
         ievent.reply('perm add failed')
 
 cmnds.add('user-addperm', handle_addperm, 'OPER')
-examples.add('user-addperm', 'user-addperm <name> <perm> .. add permissions \
-to user <name>', 'user-addperm dunker rss')
+examples.add('user-addperm', 'user-addperm <name> <perm> .. add permissions to user <name>', 'user-addperm dunker rss')
 aliases.data['setperms'] = 'user-addperm'
 aliases.data['addperms'] = 'user-addperm'
 
+## user-getperms command
+
 def handle_getperms(bot, ievent):
     """ user-getperms <name> .. get permissions of name"""
     try:
@@ -260,8 +271,7 @@ def handle_getperms(bot, ievent):
     if not users.exist(name):
         ievent.reply("can't find user %s" % name)
         return
-    perms = users.db.execute(""" SELECT perm FROM perms WHERE \
-name = %s """, name)
+    perms = users.db.execute(""" SELECT perm FROM perms WHERE name = %s """, name)
     if perms:
         permlist = []
         for i in perms:
@@ -271,10 +281,11 @@ name = %s """, name)
         ievent.reply('%s has no permissions set' % name)
 
 cmnds.add('user-getperms', handle_getperms, 'OPER')
-examples.add('user-getperms', 'user-getperms <name> .. get permissions of \
-<name>', 'user-getperms dunker')
+examples.add('user-getperms', 'user-getperms <name> .. get permissions of <name>', 'user-getperms dunker')
 aliases.data['getperms'] = 'user-getperms'
 
+## user-perms command
+
 def handle_perms(bot, ievent):
     """ user-perms .. get permission of the user given the command """
     if ievent.rest:
@@ -284,8 +295,7 @@ def handle_perms(bot, ievent):
     if not name:
          ievent.reply("can't find username for %s" % ievent.userhost)
          return
-    perms = users.db.execute(""" SELECT perm FROM perms WHERE \
-name = %s """, name)
+    perms = users.db.execute(""" SELECT perm FROM perms WHERE name = %s """, name)
     if perms:
         permlist = []
         for i in perms:
@@ -296,6 +306,8 @@ cmnds.add('user-perms', handle_perms, 'USER')
 examples.add('user-perms', 'get permissions', 'user-perms')
 aliases.data['perms'] = 'user-perms'
 
+## user-delperm command
+
 def handle_delperm(bot, ievent):
     """ user-delperm <name> <perm> .. delete permission of name """
     if len(ievent.args) != 2:
@@ -309,8 +321,7 @@ def handle_delperm(bot, ievent):
         return
     result = 0
     try:
-        result = users.db.execute(""" DELETE FROM perms WHERE name = %s AND \
-perm = %s """, (name, perm))
+        result = users.db.execute(""" DELETE FROM perms WHERE name = %s AND perm = %s """, (name, perm))
     except Exception, ex:
         ievent.reply("ERROR: %s" % str(ex))
         return
@@ -321,8 +332,9 @@ perm = %s """, (name, perm))
         return
 
 cmnds.add('user-delperm', handle_delperm, 'OPER')
-examples.add('user-delperms', 'delete from user <name> permission <perm>', \
-'user-delperms dunker rss')
+examples.add('user-delperms', 'delete from user <name> permission <perm>', 'user-delperms dunker rss')
+
+## user-addstatus command
 
 def handle_addstatus(bot, ievent):
     """ user-addstatus <name> <status> .. add status of name """
@@ -340,8 +352,7 @@ def handle_addstatus(bot, ievent):
         ievent.reply('%s already has status %s' % (name, status))
         return
     try:
-        result = users.db.execute(""" INSERT INTO statuses(name, status) \
-values(%s,%s) """, (name, status))
+        result = users.db.execute(""" INSERT INTO statuses(name, status) values(%s,%s) """, (name, status))
     except Exception, ex:
         ievent.reply("ERROR: %s" % str(ex))
         return
@@ -351,11 +362,12 @@ values(%s,%s) """, (name, status))
         ievent.reply('add failed')
 
 cmnds.add('user-addstatus', handle_addstatus, 'OPER')
-examples.add('user-addstatus', 'user-addstatus <name> <status>', \
-'user-addstatus dunker #dunkbots')
+examples.add('user-addstatus', 'user-addstatus <name> <status>', 'user-addstatus dunker #dunkbots')
 aliases.data['setstatus'] = 'user-addstatus'
 aliases.data['addstatus'] = 'user-addstatus'
 
+## user-getstatus command
+
 def handle_getstatus(bot, ievent):
     """ user-getstatus <name> .. get status of name """
     try:
@@ -367,8 +379,7 @@ def handle_getstatus(bot, ievent):
     if not users.exist(name):
         ievent.reply("can't find user %s" % name)
         return
-    status = users.db.execute(""" SELECT status FROM statuses WHERE \
-name = %s """, name)
+    status = users.db.execute(""" SELECT status FROM statuses WHERE name = %s """, name)
     if status:
         statuslist = []
         for i in status:
@@ -378,15 +389,15 @@ name = %s """, name)
         ievent.reply('%s has no status set' % name)
 
 cmnds.add('user-getstatus', handle_getstatus, 'OPER')
-examples.add('user-getstatus', 'user-getstatus <name> .. get status of \
-<name>', 'user-getstatus dunker')
+examples.add('user-getstatus', 'user-getstatus <name> .. get status of <name>', 'user-getstatus dunker')
 aliases.data['getstatus'] = 'user-getstatus'
 
+## user-status command
+
 def handle_status(bot, ievent):
     """ user-status .. get status of user given the command """
     name = users.getname(ievent.userhost)
-    status = users.db.execute(""" SELECT status FROM statuses WHERE \
-name = %s """, name)
+    status = users.db.execute(""" SELECT status FROM statuses WHERE name = %s """, name)
     if status:
         statuslist = []
         for i in status:
@@ -399,6 +410,8 @@ cmnds.add('user-status', handle_status, 'USER')
 examples.add('user-status', 'get status', 'user-status')
 aliases.data['status'] = 'user-status'
 
+## user-delstatus command
+
 def handle_delstatus(bot, ievent):
     """ user-delstatus <name> <status> .. delete status of name """
     if len(ievent.args) != 2:
@@ -412,8 +425,7 @@ def handle_delstatus(bot, ievent):
         return
     result = 0
     try:
-        result = users.db.execute(""" DELETE FROM statuses WHERE \
-name = %s AND status = %s """, (name, status))
+        result = users.db.execute(""" DELETE FROM statuses WHERE name = %s AND status = %s """, (name, status))
     except Exception, ex:
         ievent.reply("ERROR: %s" % str(ex))
         return
@@ -424,10 +436,11 @@ name = %s AND status = %s """, (name, status))
         return
 
 cmnds.add('user-delstatus', handle_delstatus, 'OPER')
-examples.add('user-delstatus', 'user-delstatus <name> <status>', \
-'user-delstatus dunker #dunkbots')
+examples.add('user-delstatus', 'user-delstatus <name> <status>', 'user-delstatus dunker #dunkbots')
 aliases.data['delstatus'] = 'user-delstatus'
 
+## user-adduserhost command
+
 def handle_adduserhost(bot, ievent):
     """ user-adduserhost <name> <userhost> .. add to userhosts of name """ 
     if len(ievent.args) != 2:
@@ -436,8 +449,7 @@ def handle_adduserhost(bot, ievent):
     name, userhost = ievent.args
     userhost = stripident(userhost)
     name = name.lower()
-    if name == 'owner' and not bot.ownercheck(ievent, 'can adduserhost to \
-owner'):
+    if name == 'owner' and not bot.ownercheck(ievent, 'can adduserhost to owner'):
         return
     if not users.exist(name):
         ievent.reply("can't find user %s" % name)
@@ -447,8 +459,7 @@ owner'):
         return
     result = 0
     try:
-        result = users.db.execute(""" INSERT INTO userhosts(name, \
-userhost) values(%s, %s) """, (name, userhost))
+        result = users.db.execute(""" INSERT INTO userhosts(name, userhost) values(%s, %s) """, (name, userhost))
     except Exception, ex:
         ievent.reply("ERROR: %s" % str(ex))
         return
@@ -458,11 +469,12 @@ userhost) values(%s, %s) """, (name, userhost))
         ievent.reply('add failed')
 
 cmnds.add('user-adduserhost', handle_adduserhost, 'OPER')
-examples.add('user-adduserhost', 'user-adduserhost <name> <userhost>', \
-'user-adduserhost dunker bart@%.a2000.nl')
+examples.add('user-adduserhost', 'user-adduserhost <name> <userhost>', 'user-adduserhost dunker bart@%.a2000.nl')
 aliases.data['adduserhost'] = 'user-adduserhost'
 aliases.data['adduserhosts'] = 'user-adduserhost'
 
+## user-deluserhost command
+
 def handle_deluserhost(bot, ievent):
     """ user-deluserhost <name> <userhost> .. remove from userhosts of name """
     if len(ievent.args) != 2:
@@ -471,33 +483,30 @@ def handle_deluserhost(bot, ievent):
     name, userhost = ievent.args
     userhost = stripident(userhost)
     name = name.lower()
-    if name == 'owner'  and not bot.ownercheck(ievent, 'can delete userhosts \
-from owner'):
+    if name == 'owner'  and not bot.ownercheck(ievent, 'can delete userhosts from owner'):
         return 
     if not users.exist(name):
         ievent.reply("can't find user %s" % name)
         return
     result = 0
     try:
-        result = users.db.execute(""" DELETE FROM userhosts WHERE \
-name = %s AND userhost = %s """, (name, userhost))
+        result = users.db.execute(""" DELETE FROM userhosts WHERE name = %s AND userhost = %s """, (name, userhost))
     except Exception, ex:
         ievent.reply("ERROR: %s" % str(ex))
         return
     if result:
         ievent.reply('userhost removed')
     else:
-        ievent.reply("%s has no %s in userhost list" % (name, \
-userhost))
+        ievent.reply("%s has no %s in userhost list" % (name, userhost))
         return  
 
 cmnds.add('user-deluserhost', handle_deluserhost, 'OPER')
-examples.add('user-deluserhost', 'user-deluserhost <name> <userhost> .. \
-delete from usershosts of <name> userhost <userhost>','user-deluserhost \
-dunker bart1@bla.a2000.nl')
+examples.add('user-deluserhost', 'user-deluserhost <name> <userhost> .. delete from usershosts of <name> userhost <userhost>','user-deluserhost dunker bart1@bla.a2000.nl')
 aliases.data['deluserhost'] = 'user-deluserhost'
 aliases.data['deluserhosts'] = 'user-deluserhost'
 
+## user-getuserhosts command
+
 def handle_getuserhosts(bot, ievent):
     """ user-getuserhosts <name> .. get userhosts of name """
     try:
@@ -506,8 +515,7 @@ def handle_getuserhosts(bot, ievent):
         ievent.missing('<name>')
         return
     who = who.lower()
-    userhosts = users.db.execute(""" SELECT userhost FROM userhosts \
-WHERE name = %s """, who)
+    userhosts = users.db.execute(""" SELECT userhost FROM userhosts WHERE name = %s """, who)
     if userhosts:
         userhostlist = []
         for i in userhosts:
@@ -517,15 +525,15 @@ WHERE name = %s """, who)
         ievent.reply("can't find user %s" % who)
 
 cmnds.add('user-getuserhosts', handle_getuserhosts, 'OPER')
-examples.add('user-getuserhosts', 'user-getuserhosts <name> .. get \
-userhosts of <name>', 'getuserhosts dunker')
+examples.add('user-getuserhosts', 'user-getuserhosts <name> .. get userhosts of <name>', 'getuserhosts dunker')
 aliases.data['getuserhosts'] = 'user-getuserhosts'
 
+## user-userhosts command
+
 def handle_userhosts(bot, ievent):
     """ user-userhosts .. get userhosts of user giving the command """
     name = users.getname(ievent.userhost)
-    userhosts = users.db.execute(""" SELECT userhost FROM userhosts \
-WHERE name = %s """, name)
+    userhosts = users.db.execute(""" SELECT userhost FROM userhosts WHERE name = %s """, name)
     if userhosts:
         userhostlist = []
         for i in userhosts:
@@ -536,6 +544,8 @@ cmnds.add('user-userhosts', handle_userhosts, 'USER')
 examples.add('user-userhosts', 'get userhosts', 'user-userhosts')
 aliases.data['userhosts'] = 'user-userhosts'
 
+## user-getemail command
+
 def handle_getemail(bot, ievent):
     """ user-getemail <name> .. get email of name """
     try:
@@ -547,18 +557,18 @@ def handle_getemail(bot, ievent):
     if not users.exist(name):
         ievent.reply("can't find user %s" % name)
         return
-    email = users.db.execute(""" SELECT email FROM email \
-WHERE name = %s """, name)
+    email = users.db.execute(""" SELECT email FROM email WHERE name = %s """, name)
     if email:
         ievent.reply(email[0][0])
     else:
         ievent.reply('no email set')
 
 cmnds.add('user-getemail', handle_getemail, 'USER')
-examples.add('user-getemail', 'user-getemail <name> .. get email from user \
-<name>', 'user-getemail dunker')
+examples.add('user-getemail', 'user-getemail <name> .. get email from user <name>', 'user-getemail dunker')
 aliases.data['getemail'] = 'user-getemail'
 
+## user-setemail command
+
 def handle_setemail(bot, ievent):
     """ user-setemail <name> .. set email of name """
     try:
@@ -573,19 +583,18 @@ def handle_setemail(bot, ievent):
     ievent.reply('email set')
 
 cmnds.add('user-setemail', handle_setemail, 'OPER')
-examples.add('user-setemail', 'user-setemail <name> <email>.. set email of \
-user <name>', 'user-setemail dunker bart@gozerbot.org')
+examples.add('user-setemail', 'user-setemail <name> <email>.. set email of user <name>', 'user-setemail dunker bart@gozerbot.org')
 aliases.data['setemail'] = 'user-setemail'
 
+## user-email command
+
 def handle_email(bot, ievent):
     """ user-email .. show email of user giving the command """
     if len(ievent.args) != 0:
-        ievent.reply('use getemail to get the email address of an user .. \
-email shows your own mail address')
+        ievent.reply('use getemail to get the email address of an user ..  email shows your own mail address')
         return
     name = users.getname(ievent.userhost)
-    email = users.db.execute(""" SELECT email FROM email \
-WHERE name = %s """, name)
+    email = users.db.execute(""" SELECT email FROM email WHERE name = %s """, name)
     if email:
         ievent.reply(email[0][0])
     else:
@@ -595,6 +604,8 @@ cmnds.add('user-email', handle_email, 'USER')
 examples.add('user-email', 'get email', 'user-email')
 aliases.data['email'] = 'user-email'
 
+## user-delemail command
+
 def handle_delemail(bot, ievent):
     """ user-delemail .. reset email of user giving the command """
     name = users.getname(ievent.userhost)
@@ -603,8 +614,7 @@ def handle_delemail(bot, ievent):
         return
     result = 0
     try:
-        result = users.db.execute(""" DELETE FROM email WHERE \
-name = %s """, name)
+        result = users.db.execute(""" DELETE FROM email WHERE name = %s """, name)
     except Exception, ex:
         ievent.reply("ERROR: %s" % str(ex))
         return
@@ -617,9 +627,10 @@ cmnds.add('user-delemail', handle_delemail, 'OPER')
 examples.add('user-delemail', 'reset email', 'user-delemail')
 aliases.data['delemail'] = 'user-delemail'
 
+## user-addpermit command
+
 def handle_addpermit(bot, ievent):
-    """ user-addpermit <name> <permit> .. add permit to permit list \
-        of <name> """
+    """ user-addpermit <name> <permit> .. add permit to permit list of <name> """
     try:
         who, what = ievent.args
     except ValueError:
@@ -634,8 +645,7 @@ def handle_addpermit(bot, ievent):
         return
     result = 0
     try:
-        result = users.db.execute(""" INSERT INTO permits(name, \
-permit) values(%s,%s) """, (name, "%s %s" % (who, what)))
+        result = users.db.execute(""" INSERT INTO permits(name, permit) values(%s,%s) """, (name, "%s %s" % (who, what)))
     except Exception, ex:
         ievent.reply("ERROR: %s" % str(ex))
         return
@@ -645,24 +655,21 @@ permit) values(%s,%s) """, (name, "%s %s" % (who, what)))
         ievent.reply('add failed')
 
 cmnds.add('user-addpermit', handle_addpermit, 'USER')
-examples.add('user-addpermit', 'user-addpermit <nick> <what> .. permit \
-nick access to <what> .. use setperms to add permissions', \
-'user-addpermit dunker todo')
+examples.add('user-addpermit', 'user-addpermit <nick> <what> .. permit nick access to <what> .. use setperms to add permissions', 'user-addpermit dunker todo')
 aliasdel('allow')
 
+## user-permit account
+
 def handle_permit(bot, ievent):
     """ user-permit .. get permit list of user giving the command """
     if ievent.rest:
-        ievent.reply("use the allow command to allow somebody something .. \
-use getname <nick> to get the username of somebody .. this command shows \
-what permits you have")
+        ievent.reply("use the allow command to allow somebody something .. use getname <nick> to get the username of somebody .. this command shows what permits you have")
         return
     name = users.getname(ievent.userhost)
     if not name:
         ievent.reply("can't find user for %s" % ievent.userhost)
         return
-    permit = users.db.execute(""" SELECT permit FROM permits \
-WHERE name = %s """, name)
+    permit = users.db.execute(""" SELECT permit FROM permits WHERE name = %s """, name)
     if permit:
         permitlist = []
         for i in permit:
@@ -672,10 +679,11 @@ WHERE name = %s """, name)
         ievent.reply("you don't have any permits")
 
 cmnds.add('user-permit', handle_permit, 'USER')
-examples.add('user-permit', 'show permit of user giving the command', \
-'user-permit')
+examples.add('user-permit', 'show permit of user giving the command', 'user-permit')
 aliases.data['permit'] = 'user-permit'
 
+## user-delpermit account
+
 def handle_userdelpermit(bot, ievent):
     """ user-delpermit <name> <permit> .. remove (name, permit) from permit 
         list """
@@ -693,8 +701,7 @@ def handle_userdelpermit(bot, ievent):
         return
     result = 0
     try:
-        result = users.db.execute(""" DELETE FROM permits WHERE \
-name = %s AND permit = %s """, (name, "%s %s" % (who, what)))
+        result = users.db.execute(""" DELETE FROM permits WHERE name = %s AND permit = %s """, (name, "%s %s" % (who, what)))
     except Exception, ex:
         ievent.reply("ERROR: %s" % str(ex))
         return
@@ -708,6 +715,8 @@ examples.add('user-delpermit', 'user-delpermit <name> <permit>', \
 'user-delpermit dunker todo')
 aliasdel('deny')
 
+## user-check command
+
 def handle_check(bot, ievent):
     """ user-check <nick> .. get user data of <nick> """
     try:
@@ -723,26 +732,20 @@ def handle_check(bot, ievent):
     if not name:
         ievent.reply("can't find user")
         return
-    userhosts = users.db.execute(""" SELECT userhost FROM userhosts \
-WHERE name = %s """, name)
-    perms = users.db.execute(""" SELECT perm FROM perms \
-WHERE name = %s """, name)
-    email = users.db.execute(""" SELECT email FROM email \
-WHERE name = %s """, name)
-    permits = users.db.execute(""" SELECT permit FROM permits \
-WHERE name = %s """, name)
-    status = users.db.execute(""" SELECT status FROM statuses \
-WHERE name = %s """, name)
-    jarig = users.db.execute(""" SELECT birthday FROM birthday \
-WHERE name = %s """, name)
-    ievent.reply('userrecord of %s = userhosts: %s perms: %s email: %s \
-permits: %s status: %s birthday: %s' % (name, str(userhosts), str(perms), \
-str(email), str(permits), str(status),str(jarig)))
+    userhosts = users.db.execute(""" SELECT userhost FROM userhosts WHERE name = %s """, name)
+    perms = users.db.execute(""" SELECT perm FROM perms WHERE name = %s """, name)
+    email = users.db.execute(""" SELECT email FROM email WHERE name = %s """, name)
+    permits = users.db.execute(""" SELECT permit FROM permits WHERE name = %s """, name)
+    status = users.db.execute(""" SELECT status FROM statuses WHERE name = %s """, name)
+    jarig = users.db.execute(""" SELECT birthday FROM birthday WHERE name = %s """, name)
+    ievent.reply('userrecord of %s = userhosts: %s perms: %s email: %s permits: %s status: %s birthday: %s' % (name, str(userhosts), str(perms), str(email), str(permits), str(status),str(jarig)))
 
 cmnds.add('user-check', handle_check, 'OPER')
 examples.add('user-check', 'user-check <nick>', 'user-check dunker')
 aliases.data['check'] = 'user-check'
 
+## user-show command
+
 def handle_show(bot, ievent):
     """ user-show <name> .. get data of <name> """
     try:
@@ -754,25 +757,18 @@ def handle_show(bot, ievent):
     if not users.exist(name):
         ievent.reply("can't find user %s" % name)
         return
-    userhosts = users.db.execute(""" SELECT userhost FROM userhosts \
-WHERE name = %s """, name)
-    perms = users.db.execute(""" SELECT perm FROM perms \
-WHERE name = %s """, name)
-    email = users.db.execute(""" SELECT email FROM email \
-WHERE name = %s """, name)
-    permits = users.db.execute(""" SELECT permit FROM permits \
-WHERE name = %s """, name)
-    status = users.db.execute(""" SELECT status FROM statuses \
-WHERE name = %s """, name)
-    jarig = users.db.execute(""" SELECT birthday FROM birthday \
-WHERE name = %s """, name)
-    ievent.reply('userrecord of %s = userhosts: %s perms: %s email: %s \
-permits: %s status: %s birthday: %s' % (name, str(userhosts), str(perms), \
-str(email), str(permits), str(status),str(jarig)))
+    userhosts = users.db.execute(""" SELECT userhost FROM userhosts WHERE name = %s """, name)
+    perms = users.db.execute(""" SELECT perm FROM perms WHERE name = %s """, name)
+    email = users.db.execute(""" SELECT email FROM email WHERE name = %s """, name)
+    permits = users.db.execute(""" SELECT permit FROM permits WHERE name = %s """, name)
+    status = users.db.execute(""" SELECT status FROM statuses WHERE name = %s """, name)
+    jarig = users.db.execute(""" SELECT birthday FROM birthday WHERE name = %s """, name)
+    ievent.reply('userrecord of %s = userhosts: %s perms: %s email: %s permits: %s status: %s birthday: %s' % (name, str(userhosts), str(perms), str(email), str(permits), str(status),str(jarig)))
 
 cmnds.add('user-show', handle_show, 'OPER')
-examples.add('user-show', 'user-show <name> .. show data of <name>', \
-'user-show dunker')
+examples.add('user-show', 'user-show <name> .. show data of <name>', 'user-show dunker')
+
+## user-match account
 
 def handle_match(bot, ievent):
     """ user-match <userhost> .. get data of <userhost> """
@@ -785,26 +781,20 @@ def handle_match(bot, ievent):
     if not name:
         ievent.reply("can't find user with userhost %s" % userhost)
         return
-    userhosts = users.db.execute(""" SELECT userhost FROM userhosts \
-WHERE name = %s """, name)
-    perms = users.db.execute(""" SELECT perm FROM perms \
-WHERE name = %s """, name)
-    email = users.db.execute(""" SELECT email FROM email \
-WHERE name = %s """, name)
-    permits = users.db.execute(""" SELECT permit FROM permits \
-WHERE name = %s """, name)
-    status = users.db.execute(""" SELECT status FROM statuses \
-WHERE name = %s """, name)
-    jarig = users.db.execute(""" SELECT birthday FROM birthday \
-WHERE name = %s """, name)
-    ievent.reply('userrecord of %s = userhosts: %s perms: %s email: %s \
-permits: %s status: %s birthday: %s' % (name, str(userhosts), str(perms), \
-str(email), str(permits), str(status),str(jarig)))
+    userhosts = users.db.execute(""" SELECT userhost FROM userhosts WHERE name = %s """, name)
+    perms = users.db.execute(""" SELECT perm FROM perms WHERE name = %s """, name)
+    email = users.db.execute(""" SELECT email FROM email WHERE name = %s """, name)
+    permits = users.db.execute(""" SELECT permit FROM permits WHERE name = %s """, name)
+    status = users.db.execute(""" SELECT status FROM statuses WHERE name = %s """, name)
+    jarig = users.db.execute(""" SELECT birthday FROM birthday WHERE name = %s """, name)
+    ievent.reply('userrecord of %s = userhosts: %s perms: %s email: %s permits: %s status: %s birthday: %s' % (name, str(userhosts), str(perms), str(email), str(permits), str(status),str(jarig)))
 
 cmnds.add('user-match', handle_match, ['USER', 'OPER'])
 examples.add('user-match', 'user-match <userhost>', 'user-match test@test')
 aliases.data['match'] = 'user-match'
 
+## user-alllstatus command
+
 def handle_getuserstatus(bot, ievent):
     """ user-allstatus <status> .. list users with status <status> """
     try:
@@ -813,8 +803,7 @@ def handle_getuserstatus(bot, ievent):
         ievent.missing('<status>')
         return
     result = []
-    userslist = users.db.execute(""" SELECT DISTINCT name FROM statuses \
-WHERE status = %s """, status)
+    userslist = users.db.execute(""" SELECT DISTINCT name FROM statuses WHERE status = %s """, status)
     if not userslist:
         ievent.reply("no users with %s status found" % status)
         return
@@ -826,8 +815,9 @@ WHERE status = %s """, status)
         ievent.reply("no users with %s status found" % status)
 
 cmnds.add('user-allstatus', handle_getuserstatus, 'OPER')
-examples.add('user-allstatus', 'user-allstatus <status> .. get all users \
-with <status> status', 'user-allstatus #dunkbots')
+examples.add('user-allstatus', 'user-allstatus <status> .. get all users with <status> status', 'user-allstatus #dunkbots')
+
+## user-allperm command
 
 def handle_getuserperm(bot, ievent):
     """ user-allperm <perm> .. list users with permission <perm> """
@@ -837,8 +827,7 @@ def handle_getuserperm(bot, ievent):
         ievent.missing('<perm>')
         return
     result = []
-    permusers = users.db.execute(""" SELECT DISTINCT name FROM perms \
-WHERE perm = %s """, perm)
+    permusers = users.db.execute(""" SELECT DISTINCT name FROM perms WHERE perm = %s """, perm)
     if not permusers:
         ievent.reply("no users with %s permission found" % perm)
         return
@@ -853,6 +842,8 @@ cmnds.add('user-allperm', handle_getuserperm, 'OPER')
 examples.add('user-allperm', 'user-allperm <perm> .. get users with \
 <perm> permission', 'user-allperm rss')
 
+## user-search command
+
 def handle_usersearch(bot, ievent):
     """ search for user matching given userhost """
     try:
@@ -860,8 +851,7 @@ def handle_usersearch(bot, ievent):
     except IndexError:
         ievent.missing('<what>')
         return
-    result = users.db.execute(""" SELECT name, userhost FROM userhosts \
-WHERE userhost LIKE %s """, '%%%s%%' % what)
+    result = users.db.execute(""" SELECT name, userhost FROM userhosts WHERE userhost LIKE %s """, '%%%s%%' % what)
     if result:
         res = []
         for i in result:
@@ -873,36 +863,4 @@ WHERE userhost LIKE %s """, '%%%s%%' % what)
 cmnds.add('user-search', handle_usersearch, 'OPER')
 examples.add('user-search', 'search users userhosts', 'user-search gozerbot')
 
-def handle_addpermall(bot, ievent):
-    """ user-addpermall <perm> .. add permission to all users """
-    try:
-        perm = ievent.args[0].upper()
-    except IndexError:
-        ievent.missing('<perm>')
-        return
-    if perm == 'OPER':
-        ievent.reply("can't add OPER permissions to all")
-        return
-    users.addpermall(perm)
-    ievent.reply('%s perm added' % perm)
-
-cmnds.add('user-addpermall', handle_addpermall, 'OPER')
-examples.add('user-addpermall', 'user-addpermall <perm> .. add <permission> \
-to all users', 'addpermsall USER')
-
-def handle_delpermall(bot, ievent):
-    """ user-delpermall <perm> .. delete permission from all users """
-    try:
-        perm = ievent.args[0].upper()
-    except IndexError:
-        ievent.missing('<perm>')
-        return
-    if perm == 'OPER':
-        ievent.reply("can't delete OPER permissions from all")
-        return
-    users.delpermall(perm)
-    ievent.reply('%s perm deleted' % perm)
-
-cmnds.add('user-delpermall', handle_delpermall, 'OPER')
-examples.add('user-delpermall', 'user-delpermall <perm> .. delete \
-<permission> from all users', 'delpermsall BLA')
+#### BHJTW 23-01-2012
