@@ -4,17 +4,25 @@
 
 """ check if host:port is open """
 
-__copyright__ = 'this file is in the public domain'
+__status__ = "seen"
+
+## gozerbot imports
 
 from gozerbot.commands import cmnds
 from gozerbot.plughelp import plughelp
 from gozerbot.examples import examples
 from gozerbot.tests import tests
 
+## basic imports
+
 import socket
 
+## plughelp
+
 plughelp.add('probe', 'show if host:port is open')
 
+## probe command
+
 def handle_probe(bot, ievent):
     """ probe <host> <port> .. check if host:port is open """
     try:
@@ -37,6 +45,7 @@ def handle_probe(bot, ievent):
     ievent.reply('%s:%s is up' % (host, port))
 
 cmnds.add('probe', handle_probe, ['OPER', 'PROBE'])
-examples.add('probe', 'probe <host> <port> // show if host:port is open', \
-'probe gozerbot.org 8088')
+examples.add('probe', 'probe <host> <port> // show if host:port is open', 'probe gozerbot.org 8088')
 tests.add('probe gozerbot.org 10101')
+
+#### BHJTW 23-01-2012
