@@ -1,7 +1,41 @@
+# gplugs/rblcheck.py
+#
 # Port from r3boot's rblcheck, with added threading support
-# (c) Wijnand 'tehmaze' Modderman - http://tehmaze.com
 # BSD License
-# (c) Lex 'r3boot' van Roon - http://r3blog.nl
+
+__author__ = " Lex 'r3boot' van Roon - http://r3blog.nl"
+__coauthor__ = "Wijnand 'tehmaze' Modderman - http://tehmaze.com"
+__status__ = "seen"
+
+## gozerbot imports
+
+from gozerbot.commands      import cmnds
+from gozerbot.generic       import rlog
+from gozerbot.persist.persistconfig import PersistConfig
+from gozerbot.users         import users
+from gozerbot.examples import examples
+from gozerbot.plughelp import plughelp
+
+## basic imports
+
+from socket    import gethostbyaddr
+from socket    import gethostbyname, gaierror
+from time      import time, sleep
+from Queue     import Queue, Empty
+from threading import Thread
+import re
+
+## plughelp
+
+plughelp.add('rblcheck', 'check blacklists')
+
+## defines
+
+cfg = PersistConfig()
+cfg.define('throttle', 60)
+cfg.define('max-threads', 5)
+cfg.define('debug', 0)
+debug = 0
 
 rbls = {}
 rbls["wl"] = {}
@@ -540,26 +574,7 @@ rbls["bl"]["zombie.dnsbl.sorbs.net"] = [
     "http://www.dnsbl.nl.sorbs.net/"
 ]
 
-from socket    import gethostbyaddr
-from socket    import gethostbyname, gaierror
-from time      import time, sleep
-from Queue     import Queue, Empty
-from threading import Thread
-import re
-from gozerbot.commands      import cmnds
-from gozerbot.generic       import rlog
-from gozerbot.persist.persistconfig import PersistConfig
-from gozerbot.users         import users
-from gozerbot.examples import examples
-from gozerbot.plughelp import plughelp
-
-plughelp.add('rblcheck', 'check blacklists')
-
-cfg = PersistConfig()
-cfg.define('throttle', 60)
-cfg.define('max-threads', 5)
-cfg.define('debug', 0)
-debug = 0
+## lict_check function
 
 def list_check(list, chkip):
     results = []
@@ -573,6 +588,8 @@ def list_check(list, chkip):
                 rlog(10, 'rblcheck', '%s result: %s' % (chk, str(qr)))
     return results
 
+## pool_check class
+
 class pool_check(object):
 
     timeout = 1.0
@@ -618,6 +635,8 @@ class pool_check(object):
                 break # no more items in queue
         self.pool.pop(0) # remove item from queue
 
+## RBLCheck class
+
 class RBLCheck(object):
     
     re_ip = re.compile('^(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$')
@@ -645,7 +664,12 @@ class RBLCheck(object):
         else:
             ievent.reply('%s is not blacklisted' % ip)
 
+## defines2
+
 rblcheck = RBLCheck()
+
 cmnds.add('rblcheck', rblcheck.handle_rblcheck, 'USER', threaded=True)
 examples.add('rblcheck', 'check <ip> with blacklists', 'rblcheck 127.0.0.1')
 
+
+#### BHJTW 23-01-2012
