@@ -2,26 +2,28 @@
 #
 #
 
-"""the rss mantra is of the following:
+"""
+    the rss mantra is of the following:
 
-as OPER:
+    as OPER:
 
-. add a url with rss-add
-. start the watcher with rss-watch
+        . add a url with rss-add
+        . start the watcher with rss-watch
 
-now the user can start the bot sending messages of the feed to him with
-rss-start. if an OPER gives a rss-start command in a channel data will be
-send to the channel.
- """
+    now the user can start the bot sending messages of the feed to him with
+    rss-start. if an OPER gives a rss-start command in a channel data will be
+    send to the channel.
+
+"""
 
-__copyright__ = 'this file is in the public domain'
 __gendocfirst__ = ['rss-add', 'rss-watch', 'rss-start']
 __gendocskip__ = ['rss-dump', ]
+__status__ = "seen"
+
+## gozerbot imports
 
-from gozerbot.utils.generic import convertpickle
 from gozerbot.persist.persist import PlugPersist
-from gozerbot.generic import geturl2, handle_exception, rlog, lockdec, \
-strippedtxt, fromenc, striphtml, useragent, jsonstring
+from gozerbot.generic import geturl2, handle_exception, rlog, lockdec, strippedtxt, fromenc, striphtml, useragent, jsonstring
 from gozerbot.utils.rsslist import rsslist
 from gozerbot.utils.statdict import Statdict
 from gozerbot.utils.lazydict import LazyDict
@@ -37,45 +39,37 @@ from gozerbot.periodical import periodical
 from gozerbot.aliases import aliasset
 from gozerbot.users import users
 from gozerbot.tests import tests
-
-from simplejson import loads
+import gozerbot.threads.thr as thr
 try:
     from gplugs.tinyurl import get_tinyurl
 except:
     def get_tinyurl(url):
         return url
 
-import gozerbot.compat.rss
+## simplejson import
+
+from simplejson import loads
+
+## basic imports
+
 import feedparser
-import gozerbot.threads.thr as thr
-import time, os, types, thread, socket, xml
+import time
+import os
+import types
+import thread
+import socket
+import xml
+
+## plughelp
 
 plughelp.add('rss', 'manage rss feeds')
 
-## UPGRADE PART
+## locks
 
-if hasattr(os, 'mkdir'):
-    if not os.path.isdir(datadir + os.sep + 'plugs' + os.sep + 'rss'):
-        os.mkdir(datadir + os.sep + 'plugs' + os.sep + 'rss')
+rsslock = thread.allocate_lock()
+locked = lockdec(rsslock)
 
-def upgrade():
-    rlog(10, 'rss', 'upgrading')
-    teller = 0
-    oldpickle = gozerbot.compat.rss.Rsswatcher(datadir + os.sep + \
-'old' + os.sep + 'rss')
-    for name, rssitem in oldpickle.data.iteritems():
-        newrssitem = Rssitem(rssitem.name, rssitem.url, rssitem.itemslist, rssitem.watchchannels, \
-rssitem.sleeptime, rssitem.running)
-        watcher.data[name] = newrssitem
-        teller += 1
-    watcher.save()
-    convertpickle(datadir + os.sep + 'rss.itemslist', datadir + os.sep + 'plugs' + \
-os.sep + 'rss' + os.sep + 'rss.itemslist')
-    convertpickle(datadir + os.sep + 'rss.markup', datadir + os.sep + 'plugs' + \
-os.sep + 'rss' + os.sep + 'rss.markup')
-    rlog(10, 'rss', 'upgraded %s items' % str(teller))
-
-## END UPGRADE PART
+## defines
 
 savelist = []
 possiblemarkup = {'separator': 'set this to desired item separator', \
@@ -85,6 +79,8 @@ possiblemarkup = {'separator': 'set this to desired item separator', \
 this to 1 if you want the rss items displayed with oldest item first', \
 'striphtml': 'strip html from output'}
 
+## txtindicts function
+
 def txtindicts(result, d):
     """ return lowlevel values in (nested) dicts """
     for j in d.values():
@@ -93,6 +89,8 @@ def txtindicts(result, d):
         else:
             result.append(j)
 
+## checkfordate function
+
 def checkfordate(data, date):
     for item in data:
         try:
@@ -103,8 +101,8 @@ def checkfordate(data, date):
             return True
     return False
 
-rsslock = thread.allocate_lock()
-locked = lockdec(rsslock)
+
+## exceptions
 
 class RssException(Exception):
     pass
@@ -121,12 +119,13 @@ class RssBozoException(RssException):
 class RssNoSuchItem(RssException):
     pass
 
+## Rssitem class
+
 class Rssitem(LazyDict):
 
     """ item that contains rss data """
 
-    def __init__(self, name="", url="", itemslist=[], watchchannels=[], \
-sleeptime=30*60, running=0, d={}):
+    def __init__(self, name="", url="", itemslist=[], watchchannels=[], sleeptime=30*60, running=0, d={}):
         if not d:
             LazyDict.__init__(self)
             self['name'] = name
@@ -140,6 +139,8 @@ sleeptime=30*60, running=0, d={}):
         else:
             LazyDict.__init__(self, d)
 
+## Rssdict class
+
 class Rssdict(PlugPersist):
 
     """ dict of rss entries """
@@ -155,8 +156,7 @@ class Rssdict(PlugPersist):
             self.data = tmp
         if self.data.has_key('itemslists'):
             del self.data['itemslists']
-        self.itemslists = Pdol(datadir + os.sep + 'plugs' + os.sep + 'rss' + \
-os.sep + filename + '.itemslists')
+        self.itemslists = Pdol(datadir + os.sep + 'plugs' + os.sep + 'rss' + os.sep + filename + '.itemslists')
         self.handlers = {}
         self.results = {}
         self.jobids = {}
@@ -164,8 +164,7 @@ os.sep + filename + '.itemslists')
         self.results = Dol()
         self.modified = {}
         self.etag = {}
-        self.markup = Pdod(datadir + os.sep + 'plugs' + os.sep + 'rss' + \
-os.sep + filename + '.markup')
+        self.markup = Pdod(datadir + os.sep + 'plugs' + os.sep + 'rss' + os.sep + filename + '.markup')
 
     def size(self):
         """ return number of rss entries """
@@ -214,11 +213,9 @@ os.sep + filename + '.markup')
         except KeyError:
             etag = None
         rlog(9, 'rss', 'fetching %s' % rssitem.url)
-        result = feedparser.parse(rssitem.url, modified=modified, etag=etag, \
-agent=useragent())
+        result = feedparser.parse(rssitem.url, modified=modified, etag=etag, agent=useragent())
         if result and result.has_key('bozo_exception'):
-            rlog(1, 'rss', '%s bozo_exception: %s' % (name, \
-result['bozo_exception']))
+            rlog(1, 'rss', '%s bozo_exception: %s' % (name, result['bozo_exception']))
         try:
             status = result.status
         except AttributeError:
@@ -240,6 +237,8 @@ result['bozo_exception']))
             self.rawresults[name] = result.entries
         return result.entries
 
+## Rsswatcher class
+
 class Rsswatcher(Rssdict):
 
     """ rss watchers """ 
@@ -280,8 +279,7 @@ class Rsswatcher(Rssdict):
                 self.watch(name)
             except Exception, ex:
                 rlog(100, 'rss', '%s feed error: %s' % (name, str(ex)))
-                rlog(100, 'rss', '%s sleeping %s seconds for retry' % \
-(name, sleeptime))
+                rlog(100, 'rss', '%s sleeping %s seconds for retry' % (name, sleeptime))
                 time.sleep(sleeptime)
                 if not rssitem.running:
                     break
@@ -336,48 +334,31 @@ class Rsswatcher(Rssdict):
                 self.itemslists.extend(jsonstring([name, channel]), rssitem.itemslist)
                 self.itemslists.save()
         for j in res:
-            if self.markup.get(jsonstring([name, channel]), \
-'skipmerge') and 'Merge branch' in j['title']:
+            if self.markup.get(jsonstring([name, channel]), 'skipmerge') and 'Merge branch' in j['title']:
                 continue
             resultstr = u""
             for i in self.itemslists[jsonstring([name, channel])]:
-
                 try:
                     item = unicode(j[i])
-
-                    if not item:
-                        continue
-
+                    if not item: continue
                     if item.startswith('http://'):
-
-                        if self.markup.get(jsonstring([name, channel]), \
-'tinyurl'):
+                        if self.markup.get(jsonstring([name, channel]), 'tinyurl'):
                             try:
                                 tinyurl = get_tinyurl(item)
-
-                                if not tinyurl:
-                                    resultstr += u"<%s> - " % item
-                                else:
-                                    resultstr += u"<%s> - " % tinyurl[0]
-
+                                if not tinyurl: resultstr += u"<%s> - " % item
+                                else: resultstr += u"<%s> - " % tinyurl[0]
                             except Exception, ex:
                                 handle_exception()
                                 resultstr += u"<%s> - " % item
-
                         else:
                             resultstr += u"<%s> - " % item
-
                     elif self.markup.get(jsonstring([name, channel]) , 'striphtml'):
                         resultstr += u"%s - " % striphtml(item.strip())
-
                     else:
                         resultstr += u"%s - " % item.strip()
-                    
-                except KeyError:
-                    continue
+                except KeyError: continue
             resultstr = resultstr[:-3]
-            if resultstr:
-                result += u"%s %s " % (resultstr, sep)
+            if resultstr: result += u"%s %s " % (resultstr, sep)
         return result[:-(len(sep)+2)]
 
     def peek(self, name, *args):
@@ -416,8 +397,7 @@ class Rsswatcher(Rssdict):
                     try:
                         (botname, channel) = loads(item)
                     except:
-                        rlog(10, 'rss', '%s is not in the format \
-(botname,channel)' % str(item))
+                        rlog(10, 'rss', '%s is not in the format (botname,channel)' % str(item))
                 bot = fleet.byname(botname)
                 if not bot:
                     continue
@@ -426,17 +406,14 @@ class Rsswatcher(Rssdict):
                 if self.markup.get(jsonstring([name, channel]), 'all-lines'):
                     for i in res2:
                         response = self.makeresponse(name, [i, ], channel)
-                        bot.say(channel, "\002%s\002: %s" % \
-(rssitem.name, response), fromm=rssitem.name)
+                        bot.say(channel, "\002%s\002: %s" % (rssitem.name, response), fromm=rssitem.name)
                 else:
                     sep =  self.markup.get(jsonstring([name, channel]), 'separator')
                     if sep:
-                        response = self.makeresponse(name, res2, channel, \
-sep=sep)
+                        response = self.makeresponse(name, res2, channel, sep=sep)
                     else:
                         response = self.makeresponse(name, res2, channel)
-                    bot.say(channel, "\002%s\002: %s" % (rssitem.name, \
-response), fromm=rssitem.name)
+                    bot.say(channel, "\002%s\002: %s" % (rssitem.name, response), fromm=rssitem.name)
         except Exception, ex:
             handle_exception(txt=name)
 
@@ -554,22 +531,32 @@ response), fromm=rssitem.name)
                 res.append(txt)
         return res
 
+## defines2
+
 watcher = Rsswatcher('rss')
 
+3## init function
+
 def init(): 
     """ called after plugin import """
     thr.start_new_thread(watcher.startwatchers, ())
     return 1
 
+## size function
+
 def size():
     """ return number of watched rss entries """
     return watcher.size()
 
+## shutdown function
+
 def shutdown():
     """ called before plugin import """
     watcher.stopwatchers()
     return 1
-    
+
+## rss-add command
+
 def handle_rssadd(bot, ievent):
     """ rss-add <name> <url> .. add a rss item """
     try:
@@ -585,6 +572,8 @@ examples.add('rss-add', 'rss-add <name> <url> to the rsswatcher', 'rss-add \
 gozerbot http://core.gozerbot.org/hg/dev/0.9/rss-log')
 tests.add('rss-add dev http://core.gozerbot.org/hg/dev/0.9/rss-log')
 
+## rss-del command
+
 def handle_rssdel(bot, ievent):
     """ rss-del <name> .. delete a rss item """
     try:
@@ -604,6 +593,8 @@ examples.add('rss-del', 'rss-del <name> .. remove <name> from the \
 rsswatcher', 'rss-del mekker')
 tests.add('rss-del mekker')
 
+## rss-watch command
+
 def handle_rsswatch(bot, ievent):
     """ rss-watch <name> .. start watcher thread """
     if not ievent.channel:
@@ -650,6 +641,8 @@ examples.add('rss-watch', 'rss-watch <name> [seconds to sleep] .. go \
 watching <name>', '1) rss-watch gozerbot 2) rss-watch gozerbot 600')
 tests.add('rss-watch')
 
+## rss-start command
+
 def handle_rssstart(bot, ievent):
     """ rss-start <name> .. start a rss feed to a user """
     if ievent.rest == 'all':
@@ -682,8 +675,7 @@ def handle_rssstart(bot, ievent):
             ievent.reply('%s watcher is not running' % name)
             continue
         if jsonstring([bot.name, target]) in rssitem.watchchannels or [bot.name, target] in rssitem.watchchannels:
-            ievent.reply('we are already monitoring %s on (%s,%s)' % \
-(name, bot.name, target))
+            ievent.reply('we are already monitoring %s on (%s,%s)' % (name, bot.name, target))
             continue
         rssitem.watchchannels.append([bot.name, target])
         watcher.itemslists.adduniq(jsonstring([name, target]), 'title')
@@ -700,6 +692,8 @@ examples.add('rss-start', 'rss-start <name> .. start a rss feed \
 (per user/channel) ', 'rss-start gozerbot')
 tests.add('rss-start dev')
 
+## rss-stop command
+
 def handle_rssstop(bot, ievent):
     """ rss-start <name> .. start a rss feed to a user """
     if not ievent.rest:
@@ -726,17 +720,17 @@ def handle_rssstop(bot, ievent):
         try:
             rssitem.watchchannels.remove([bot.name, target])
         except ValueError:
-            ievent.reply('we are not monitoring %s on (%s,%s)' % \
-(name, bot.name, target))
+            ievent.reply('we are not monitoring %s on (%s,%s)' % (name, bot.name, target))
             return
     watcher.save()
     ievent.reply('%s stopped' % name)
 
 cmnds.add('rss-stop', handle_rssstop, ['RSS', 'USER'])
-examples.add('rss-stop', 'rss-stop <name> .. stop a rss feed \
-(per user/channel) ', 'rss-stop gozerbot')
+examples.add('rss-stop', 'rss-stop <name> .. stop a rss feed (per user/channel) ', 'rss-stop gozerbot')
 tests.add('rss-stop mekker')
 
+## rss-channels command
+
 def handle_rsschannels(bot, ievent):
     """ rss-channels <name> .. show channels of rss feed """
     try:
@@ -757,10 +751,11 @@ def handle_rsschannels(bot, ievent):
     ievent.reply("channels of %s: " % name, result, dot=True)
 
 cmnds.add('rss-channels', handle_rsschannels, 'OPER')
-examples.add('rss-channels', 'rss-channels <name> .. show channels', \
-'rss-channels gozerbot')
+examples.add('rss-channels', 'rss-channels <name> .. show channels', 'rss-channels gozerbot')
 tests.add('rss-channels')
 
+## rss-addchannel command
+
 def handle_rssaddchannel(bot, ievent):
     """ rss-addchannel <name> [<botname>] <channel> .. add a channel to \
         rss item """
@@ -786,20 +781,19 @@ def handle_rssaddchannel(bot, ievent):
         ievent.reply('%s watcher is not running' % name)
         return
     if jsonstring([botname, channel]) in rssitem.watchchannels or [botname, channel] in rssitem.watchchannels:
-        ievent.reply('we are already monitoring %s on (%s,%s)' % \
-(name, botname, channel))
+        ievent.reply('we are already monitoring %s on (%s,%s)' % (name, botname, channel))
         return
     rssitem.watchchannels.append([botname, channel])
     watcher.save()
     ievent.reply('%s added to %s rss item' % (channel, name))
 
 cmnds.add('rss-addchannel', handle_rssaddchannel, 'OPER')
-examples.add('rss-addchannel', 'rss-addchannel <name> [<botname>] <channel> \
-..add <channel> or <botname> <channel> to watchchannels of <name>', \
-'1) rss-addchannel gozerbot #dunkbots 2) rss-addchannel gozerbot main \
-#dunkbots')
+examples.add('rss-addchannel', 'rss-addchannel <name> [<botname>] <channel>, add <channel> or <botname> <channel> to watchchannels of <name>', \
+'1) rss-addchannel gozerbot #dunkbots 2) rss-addchannel gozerbot main #dunkbots')
 tests.add('rss-addchannel dev exec')
 
+## rss-setitems command
+
 def handle_rsssetitems(bot, ievent):
     try:
         (name, items) = ievent.args[0], ievent.args[1:]
@@ -818,10 +812,11 @@ def handle_rsssetitems(bot, ievent):
     ievent.reply('%s added to (%s,%s) itemslist' % (items, name, target))
 
 cmnds.add('rss-setitems', handle_rsssetitems, ['RSS', 'USER'])
-examples.add('rss-setitems', 'set tokens of the itemslist (per user/channel)',\
- 'rss-setitems gozerbot author author link pubDate')
+examples.add('rss-setitems', 'set tokens of the itemslist (per user/channel)', 'rss-setitems gozerbot author author link pubDate')
 tests.add('rss-setitems dev link author')
 
+## rss-additem command
+
 def handle_rssadditem(bot, ievent):
     try:
         (name, item) = ievent.args
@@ -840,10 +835,11 @@ def handle_rssadditem(bot, ievent):
     ievent.reply('%s added to (%s,%s) itemslist' % (item, name, target))
 
 cmnds.add('rss-additem', handle_rssadditem, ['RSS', 'USER'])
-examples.add('rss-additem', 'add a token to the itemslist (per user/channel)',\
- 'rss-additem gozerbot link')
+examples.add('rss-additem', 'add a token to the itemslist (per user/channel)', 'rss-additem gozerbot link')
 tests.add('rss-additem dev link')
 
+## rss-delitem command
+
 def handle_rssdelitem(bot, ievent):
     try:
         (name, item) = ievent.args
@@ -866,18 +862,20 @@ def handle_rssdelitem(bot, ievent):
     ievent.reply('%s removed from (%s,%s) itemslist' % (item, name, target))
 
 cmnds.add('rss-delitem', handle_rssdelitem, ['RSS', 'USER'])
-examples.add('rss-delitem', 'remove a token from the itemslist \
-(per user/channel)', 'rss-delitem gozerbot link')
+examples.add('rss-delitem', 'remove a token from the itemslist (per user/channel)', 'rss-delitem gozerbot link')
 tests.add('rss-delitem')
 
+## rss-markuplist command
+
 def handle_rssmarkuplist(bot, ievent):
     ievent.reply('possible markups ==> ' , possiblemarkup, dot=True)
 
 cmnds.add('rss-markuplist', handle_rssmarkuplist, 'USER')
-examples.add('rss-markuplist', 'show possible markup entries', \
-'rss-markuplist')
+examples.add('rss-markuplist', 'show possible markup entries', 'rss-markuplist')
 tests.add('rss-markuplist')
 
+## rss-markup command
+
 def handle_rssmarkup(bot, ievent):
     try:
         name = ievent.args[0]
@@ -894,10 +892,11 @@ def handle_rssmarkup(bot, ievent):
         pass
 
 cmnds.add('rss-markup', handle_rssmarkup, ['RSS', 'USER'])
-examples.add('rss-markup', 'show markup list for a feed (per user/channel)', \
-'rss-markup gozerbot')
+examples.add('rss-markup', 'show markup list for a feed (per user/channel)', 'rss-markup gozerbot')
 tests.add('rss-markup dev')
 
+## rss-addmarkup command
+
 def handle_rssaddmarkup(bot, ievent):
     try:
         (name, item, value) = ievent.args
@@ -920,10 +919,11 @@ def handle_rssaddmarkup(bot, ievent):
         ievent.reply("no (%s,%s) feed available" % (name, target))
 
 cmnds.add('rss-addmarkup', handle_rssaddmarkup, ['RSS', 'USER'])
-examples.add('rss-addmarkup', 'add a markup option to the markuplist \
-(per user/channel)', 'rss-addmarkup gozerbot all-lines 1')
+examples.add('rss-addmarkup', 'add a markup option to the markuplist (per user/channel)', 'rss-addmarkup gozerbot all-lines 1')
 tests.add('rss-addmarkup dev')
 
+## rss-delmarkup command
+
 def handle_rssdelmarkup(bot, ievent):
     try:
         (name, item) = ievent.args
@@ -943,10 +943,11 @@ def handle_rssdelmarkup(bot, ievent):
     ievent.reply('%s removed from (%s,%s) markuplist' % (item, name, target))
 
 cmnds.add('rss-delmarkup', handle_rssdelmarkup, ['RSS', 'USER'])
-examples.add('rss-delmarkup', 'remove a markup option from the markuplist \
-(per user/channel)', 'rss-delmarkup gozerbot all-lines')
+examples.add('rss-delmarkup', 'remove a markup option from the markuplist (per user/channel)', 'rss-delmarkup gozerbot all-lines')
 tests.add('rss-delmarkup dev all-lines')
 
+## rss-delchannel command
+
 def handle_rssdelchannel(bot, ievent):
     """ rss-delchannel <name> [<botname>] <channel> .. delete channel \
         from rss item """
@@ -982,12 +983,12 @@ channel))
     watcher.save()
 
 cmnds.add('rss-delchannel', handle_rssdelchannel, 'OPER')
-examples.add('rss-delchannel', 'rss-delchannel <name> [<botname>] \
-[<channel>] .. delete <channel> or <botname> <channel> from watchchannels of \
-<name>', '1) rss-delchannel gozerbot #dunkbots 2) rss-delchannel gozerbot \
-main #dunkbots')
+examples.add('rss-delchannel', 'rss-delchannel <name> [<botname>] [<channel>] .. delete <channel> or <botname> <channel> from watchchannels of \
+<name>', '1) rss-delchannel gozerbot #dunkbots 2) rss-delchannel gozerbot main #dunkbots')
 tests.add('rss-delchannel dev exec')
 
+## rss-stopwatch command
+
 def handle_rssstopwatch(bot, ievent):
     """ rss-stopwatch <name> .. stop a watcher thread """
     try:
@@ -1005,10 +1006,11 @@ def handle_rssstopwatch(bot, ievent):
     ievent.reply('stopped %s rss watch' % name)
 
 cmnds.add('rss-stopwatch', handle_rssstopwatch, 'OPER')
-examples.add('rss-stopwatch', 'rss-stopwatch <name> .. stop polling <name>', \
-'rss-stopwatch gozerbot')
+examples.add('rss-stopwatch', 'rss-stopwatch <name> .. stop polling <name>', 'rss-stopwatch gozerbot')
 tests.add('rss-stopwatch makker')
 
+## rss-sleepttime command
+
 def handle_rsssleeptime(bot, ievent):
     """ rss-sleeptime <name> .. get sleeptime of rss item """
     try:
@@ -1027,10 +1029,11 @@ str(rssitem.sleeptime)))
         ievent.reply("can't get sleeptime for %s" % name)
 
 cmnds.add('rss-sleeptime', handle_rsssleeptime, 'OPER')
-examples.add('rss-sleeptime', 'rss-sleeptime <name> .. get sleeping time \
-for <name>', 'rss-sleeptime gozerbot')
+examples.add('rss-sleeptime', 'rss-sleeptime <name> .. get sleeping time for <name>', 'rss-sleeptime gozerbot')
 tests.add('rss-sleeptime dev')
 
+## rss-setsleeptime command
+
 def handle_rsssetsleeptime(bot, ievent):
     """ rss-setsleeptime <name> <seconds> .. set sleeptime of rss item """
     try:
@@ -1057,10 +1060,11 @@ def handle_rsssetsleeptime(bot, ievent):
     ievent.reply('sleeptime set')
 
 cmnds.add('rss-setsleeptime', handle_rsssetsleeptime, 'OPER')
-examples.add('rss-setsleeptime', 'rss-setsleeptime <name> <seconds> .. set \
-sleeping time for <name> .. min 60 sec', 'rss-setsleeptime gozerbot 600')
+examples.add('rss-setsleeptime', 'rss-setsleeptime <name> <seconds> .. set sleeping time for <name> .. min 60 sec', 'rss-setsleeptime gozerbot 600')
 tests.add('rss-setsleeptime dev 60')
 
+## rss-get command
+
 def handle_rssget(bot, ievent):
     """ rss-get  <name> .. fetch rss data """
     try:
@@ -1085,8 +1089,7 @@ def handle_rssget(bot, ievent):
     if go:
         for i in result:
             response = watcher.makeresponse(name, [i, ], channel)
-            bot.say(channel, "\002%s\002: %s" % (rssitem.name, response), \
-fromm=rssitem.name)
+            bot.say(channel, "\002%s\002: %s" % (rssitem.name, response), fromm=rssitem.name)
     else:
         response = watcher.makeresponse(name, result, ievent.channel)
         if response:
@@ -1095,10 +1098,11 @@ fromm=rssitem.name)
             ievent.reply("can't match watcher data")
 
 cmnds.add('rss-get', handle_rssget, ['RSS', 'USER'], threaded=True)
-examples.add('rss-get', 'rss-get <name> .. get data from <name>', \
-'rss-get gozerbot')
+examples.add('rss-get', 'rss-get <name> .. get data from <name>', 'rss-get gozerbot')
 tests.add('rss-get dev')
 
+## rss-runnig command
+
 def handle_rssrunning(bot, ievent):
     """ rss-running .. show which watchers are running """
     result = watcher.runners()
@@ -1112,10 +1116,11 @@ def handle_rssrunning(bot, ievent):
         ievent.reply('nothing running yet')
 
 cmnds.add('rss-running', handle_rssrunning, ['RSS', 'USER'])
-examples.add('rss-running', 'rss-running .. get running rsswatchers', \
-'rss-running')
+examples.add('rss-running', 'rss-running .. get running rsswatchers', 'rss-running')
 tests.add('rss-running')
 
+## rss-list command
+
 def handle_rsslist(bot, ievent):
     """ rss-list .. return list of rss items """
     result = watcher.list()
@@ -1129,6 +1134,8 @@ cmnds.add('rss-list', handle_rsslist, ['RSS', 'USER'])
 examples.add('rss-list', 'get list of rss items', 'rss-list')
 tests.add('rss-list')
 
+## rss-url command
+
 def handle_rssurl(bot, ievent):
     """ rss-url <name> .. return url of rss item """
     try:
@@ -1153,10 +1160,11 @@ def handle_rssurl(bot, ievent):
     ievent.reply('url of %s: %s' % (name, result))
 
 cmnds.add('rss-url', handle_rssurl, ['RSS', 'OPER'])
-examples.add('rss-url', 'rss-url <name> .. get url from rssitem with \
-<name>', 'rss-url gozerbot')
+examples.add('rss-url', 'rss-url <name> .. get url from rssitem with <name>', 'rss-url gozerbot')
 tests.add('rss-url dev')
 
+## rss-seturl command
+
 def handle_rssseturl(bot, ievent):
     """ rss-seturl <name> <url> .. set url of rss item """
     try:
@@ -1177,9 +1185,10 @@ url))
         ievent.reply('failed to set url of %s to %s' % (name, url))
 
 cmnds.add('rss-seturl', handle_rssseturl, ['RSS', 'OPER'])
-examples.add('rss-seturl', 'rss-seturl <name> <url> .. change url of rssitem',\
-'rss-seturl gozerbot http://core.gozerbot.org/hg/dev/0.9/rss-log')
-tests.add('rss-seturl dev http://core.gozerbot.org/hg/dev/0.9/rss-list')
+examples.add('rss-seturl', 'rss-seturl <name> <url> .. change url of rssitem', 'rss-seturl gozerbot https://pikacode.com/bthate/gozerbot/rss/default/')
+tests.add('rss-seturl dev https://pikacode.com/bthate/gozerbot/rss/default/')
+
+## rss-itemslist command
 
 def handle_rssitemslist(bot, ievent):
     """ rss-itemslist <name> .. show itemslist of rss item """
@@ -1191,17 +1200,16 @@ def handle_rssitemslist(bot, ievent):
     try:
         itemslist = watcher.itemslists[jsonstring([name, ievent.channel.lower()])]
     except KeyError:
-        ievent.reply("no itemslist set for (%s, %s)" % (name, \
-ievent.channel.lower()))
+        ievent.reply("no itemslist set for (%s, %s)" % (name, ievent.channel.lower()))
         return
-    ievent.reply("itemslist of (%s, %s): " % (name, ievent.channel.lower()), \
-itemslist, dot=True)
+    ievent.reply("itemslist of (%s, %s): " % (name, ievent.channel.lower()), itemslist, dot=True)
 
 cmnds.add('rss-itemslist', handle_rssitemslist, ['RSS', 'USER'])
-examples.add('rss-itemslist', 'rss-itemslist <name> .. get itemslist of \
-<name> ', 'rss-itemslist gozerbot')
+examples.add('rss-itemslist', 'rss-itemslist <name> .. get itemslist of <name> ', 'rss-itemslist gozerbot')
 tests.add('rss-itemslist dev')
 
+## rss-scan command
+
 def handle_rssscan(bot, ievent):
     """ rss-scan <name> .. scan rss item for used xml items """
     try:
@@ -1226,10 +1234,11 @@ def handle_rssscan(bot, ievent):
     ievent.reply("tokens of %s: " % name, res)
 
 cmnds.add('rss-scan', handle_rssscan, 'OPER')
-examples.add('rss-scan', 'rss-scan <name> .. get possible items of <name> ', \
-'rss-scan gozerbot')
+examples.add('rss-scan', 'rss-scan <name> .. get possible items of <name> ', 'rss-scan gozerbot')
 tests.add('rss-scan dev')
 
+## rss-sync command
+
 def handle_rsssync(bot, ievent):
     """ rss-sync <name> .. sync rss item data """
     try:
@@ -1244,10 +1253,11 @@ def handle_rsssync(bot, ievent):
         ievent.reply("%s error: %s" % (name, str(ex)))
 
 cmnds.add('rss-sync', handle_rsssync, 'OPER')
-examples.add('rss-sync', 'rss-sync <name> .. sync data of <name>', \
-'rss-sync gozerbot')
+examples.add('rss-sync', 'rss-sync <name> .. sync data of <name>', 'rss-sync gozerbot')
 tests.add('rss-sync dev')
 
+## rss-feeds command
+
 def handle_rssfeeds(bot, ievent):
     """ rss-feeds <channel> .. show what feeds are running in a channel """
     try:
@@ -1264,10 +1274,11 @@ def handle_rssfeeds(bot, ievent):
         ievent.reply("ERROR: %s" % str(ex))
 
 cmnds.add('rss-feeds', handle_rssfeeds, ['USER', 'RSS'])
-examples.add('rss-feeds', 'rss-feeds <name> .. show what feeds are running \
-in a channel', '1) rss-feeds 2) rss-feeds #dunkbots')
+examples.add('rss-feeds', 'rss-feeds <name> .. show what feeds are running in a channel', '1) rss-feeds 2) rss-feeds #dunkbots')
 tests.add('rss-feeds')
 
+## rss-link command
+
 def handle_rsslink(bot, ievent):
     try:
         feed, rest = ievent.rest.split(' ', 1)
@@ -1286,10 +1297,11 @@ def handle_rsslink(bot, ievent):
         return
 
 cmnds.add('rss-link', handle_rsslink, ['RSS', 'USER'])
-examples.add('rss-link', 'give link of item which title matches search key', \
-'rss-link gozerbot gozer')
+examples.add('rss-link', 'give link of item which title matches search key', 'rss-link gozerbot gozer')
 tests.add('rss-link dev gozerbot')
 
+## rss-descroption command
+
 def handle_rssdescription(bot, ievent):
     try:
         feed, rest = ievent.rest.split(' ', 1)
@@ -1299,17 +1311,17 @@ def handle_rssdescription(bot, ievent):
     rest = rest.strip().lower()
     res = ""
     try:
-        ievent.reply(watcher.search(feed, 'description', rest), \
-dot=" \002||\002 ")
+        ievent.reply(watcher.search(feed, 'description', rest), dot=" \002||\002 ")
     except KeyError:
         ievent.reply('no %s feed data available' % feed)
         return
 
 cmnds.add('rss-description', handle_rssdescription, ['RSS', 'USER'])
-examples.add('rss-description', 'give description of item which title \
-matches search key', 'rss-description gozerbot gozer')
+examples.add('rss-description', 'give description of item which title matches search key', 'rss-description gozerbot gozer')
 tests.add('rss-description')
 
+## rss-all command
+
 def handle_rssall(bot, ievent):
     try:
         feed = ievent.args[0]
@@ -1326,6 +1338,8 @@ cmnds.add('rss-all', handle_rssall, ['RSS', 'USER'])
 examples.add('rss-all', "give titles of a feed", 'rss-all gozerbot')
 tests.add('rss-all dev')
 
+## rss-search command
+
 def handle_rsssearch(bot, ievent):
     try:
         txt = ievent.args[0]
@@ -1339,10 +1353,11 @@ def handle_rsssearch(bot, ievent):
         return
 
 cmnds.add('rss-search', handle_rsssearch, ['RSS', 'USER'])
-examples.add('rss-search', "search titles of all current feeds", \
-'rss-search goz')
+examples.add('rss-search', "search titles of all current feeds", 'rss-search goz')
 tests.add('rss-search gozerbot')
 
+## rss-dump command
+
 def handle_rssdump(bot, ievent):
     try:
         ievent.reply(str(watcher.rawresults[ievent.rest]))
@@ -1353,6 +1368,8 @@ cmnds.add('rss-dump', handle_rssdump, 'OPER')
 examples.add('rss-dump', 'dump cached rss data', 'rss-dump')
 tests.add('rss-dump dev')
 
+## rss-peek command
+
 def handle_rsspeek(bot, ievent):
     if not ievent.rest:
         ievent.missing('<feedname>')
@@ -1361,3 +1378,5 @@ def handle_rsspeek(bot, ievent):
 
 cmnds.add('rss-peek', handle_rsspeek, 'OPER')
 tests.add('rss-peek dev')
+
+#### BHJTW 23-01-2012
