@@ -2,6 +2,10 @@
 #
 #
 
+__status__ = "seen"
+
+## gozerbot imports
+
 from gozerbot.generic import handle_exception
 from gozerbot.commands import cmnds
 from gozerbot.plugins import plugins
@@ -10,10 +14,16 @@ from gozerbot.plughelp import plughelp
 from gozerbot.examples import examples
 from gozerbot.tests import tests
 
+## basic imports
+
 import Queue
 
+## plughelp
+
 plughelp.add('search', 'search all plugins that provide a search() function')
 
+## search command
+
 def handle_search(bot, ievent):
     """ search all plugins that provide a search() function """
     result = {}
@@ -49,3 +59,5 @@ def handle_search(bot, ievent):
 cmnds.add('search', handle_search, ['USER', 'CLOUD', 'WEB'])
 examples.add('search', 'search all bot data for <item>', 'search gozer')
 tests.add('search', 'search gozerbot')
+
+#### BHJTW 23-01-2012
