@@ -2,22 +2,34 @@
 #
 #
 
-__copyright__ = 'this file is in the public domain'
 __thnx__ = 'thnx to snore for this one'
+__status__ = "seen"
+
+## gozerbot imports
 
 from gozerbot.commands import cmnds
 from gozerbot.examples import examples
 from gozerbot.plughelp import plughelp
 from gozerbot.tests import tests
 
-import os, string, random
+## basic imports
+
+import os
+import string
+import random
+
+## plughelp
 
 plughelp.add('wisdom', 'show some wisdom')
 
+## vars
+
 excuses = ['booo', ]
 matrix = ['booo', ]
 motivation = ['booo', ]
 
+## init function
+
 def init():
     global excuses
     global matrix
@@ -27,32 +39,41 @@ def init():
     motivation = motivationtxt.splitlines()
     return 1
 
+## matrix command
+
 def handle_matrix(bot, ievent):
     """ get a matrix quote """
     rand = random.randint(1,len(matrix))
     ievent.reply(matrix[rand-1].strip())
 
+cmnds.add('matrix', handle_matrix, 'USER')
+examples.add('matrix', 'get a matrix quote', 'matrix')
+tests.add('matrix')
+
+## excuse command
+
 def handle_excuse(bot, ievent):
     """ get an excuse """
     rand = random.randint(1,len(excuses))
     ievent.reply(excuses[rand-1].strip())
 
+cmnds.add('excuse', handle_excuse, 'USER')
+examples.add('excuse', 'get an excuse', 'excuse')
+tests.add('matrix')
+
+## motivation command
+
 def handle_motivation(bot, ievent):
     """ get despair  """
     rand = random.randint(1,len(motivation))
     ievent.reply(motivation[rand-1].strip())
 
-
-cmnds.add('matrix', handle_matrix, 'USER')
-examples.add('matrix', 'get a matrix quote', 'matrix')
-tests.add('matrix')
-cmnds.add('excuse', handle_excuse, 'USER')
-examples.add('excuse', 'get an excuse', 'excuse')
-tests.add('matrix')
 cmnds.add('motivation', handle_motivation, 'USER')
 examples.add('motivation', 'get motivated', 'motivation')
 tests.add('motivation')
 
+## defines
+
 excusestxt = """
 clock speed
 solar flares
@@ -628,3 +649,5 @@ Underachievement: The tallest blade of grass is the first to be cut by the lawnm
 Wishes: When you wish upon a falling star, your dreams can come true. Unless it's really a meteorite hurtling to the Earth which will destroy all life. Then you're pretty much hosed no matter what you wish for. Unless it's death by meteor. 
 Worth: Just because you're necessary doesn't mean you're important.
 """
+
+#### BHJTW 23-01-2012
