@@ -1,38 +1,46 @@
+# gplugs/yahoo.py
+#
 # Yahoo! search
 # (c) Wijnand 'tehmaze' Modderman - http://tehmaze.com
 # (c) Leif Hedstrom <leif@ogre.com>, creator of pYsearch (License: BSD)
 
 __author__ = 'Wijnand Modderman <gozerbot@tehmaze.com>'
 __copyright__ = 'BSD'
+__status__ = "seen"
+
+## gozerbot imports
 
-import time
-import urllib
-import xml.dom.minidom
 from gozerbot.aliases import aliases
 from gozerbot.commands import cmnds
 from gozerbot.generic import geturl, waitforqueue
 from gozerbot.persist.persistconfig import PersistConfig
 from gozerbot.plughelp import plughelp
 
+## basic imports
+
+import time
+import urllib
+import xml.dom.minidom
+
+## plughelp
+
 plughelp.add('yahoo', 'query yahoo search engine')
 
+## defines
+
 cfg = PersistConfig()
 cfg.define('appid', '')
 
-# Function: string_to_bool
-#   Convert a string argument to a boolean
-#
-# Parmeters:
-#   s - The input string
-#
-# Returns:
-#   bool
+## string_to_bool function
+
 def string_to_bool(s):
     sb = {'false': False, 'true': True}
-    if sb.has_key(s.lower()):
-        return sb[s.lower()]
+    if sb.has_key(s.lower()): return sb[s.lower()]
     return bool(s)
 
+
+## START API
+
 class YahooException(Exception):
     pass
 
@@ -42,6 +50,8 @@ class YahooError(Exception):
 class YahooXMLError(Exception):
     pass
 
+## YahooRresultDict class
+
 class YahooResultDict(dict):
     def __getattr__(self, key):
         try:
@@ -49,13 +59,10 @@ class YahooResultDict(dict):
         except KeyError:
             raise AttributeError("Result object has no attribute '%s'" % key)
 
-# Class: YahooResultParser
-#   Parse the results found by a <YahooResultParser> 
+## YahooResultParser class
+
 class YahooResultParser(object):
-    # Constructor: __init__
-    # Parameters:
-    #   service - ...
-    #   res_dict - ...
+
     def __init__(self, service, res_dict=YahooResultDict):
         self._service = service
         self._total_results_available = 0
@@ -79,6 +86,7 @@ class YahooResultParser(object):
     def _get_results(self):
         """Get the results."""
         return self._results
+
     results = property(_get_results, None, None,
                        "The list of all results")
 
@@ -88,6 +96,7 @@ class YahooResultParser(object):
     def _set_service(self, service):
         """Set the service for this DOM parser."""
         self._service = service
+
     service = property(_get_service, _set_service, None,
                        "The Search Web Service object for this results parser")
 
@@ -104,18 +113,16 @@ class YahooResultParser(object):
     def _get_total_results_returned(self):
         """Get the number of results returned."""
         return self._total_results_returned
-    total_results_returned = property(_get_total_results_returned, None, None,
-                                      "The number of results returned")
-    totalResultsReturned = property(_get_total_results_returned, None, None,
-                                    "The number of results returned")
+
+    total_results_returned = property(_get_total_results_returned, None, None, "The number of results returned")
+    totalResultsReturned = property(_get_total_results_returned, None, None, "The number of results returned")
 
     def _get_first_result_position(self):
         """Get the first result position."""
         return self._first_result_position
-    first_result_position = property(_get_first_result_position, None, None,
-                                     "The first result position")
-    firstResultPosition = property(_get_first_result_position, None, None,
-                                   "The first result position") 
+
+    first_result_position = property(_get_first_result_position, None, None, "The first result position")
+    firstResultPosition = property(_get_first_result_position, None, None, "The first result position") 
 
 class YahooDOMResultParser(YahooResultParser):
     """DomResultParser - Base class for Yahoo Search DOM result parsers
@@ -514,8 +521,12 @@ class Yahoo:
     def videoSearch(self, query, format='any', adult_ok=0, results=10):
         return self._get('VideoSearch', {'query': query, 'format': format, 'results': results, 'adult_ok': adult_ok})
 
+## vars
+
 yahoo = Yahoo()
 
+## yahoo-image command
+
 def handle_yahoo_image(bot, ievent):
     adult_ok = 0
     format = ''
@@ -555,6 +566,8 @@ def handle_yahoo_image(bot, ievent):
 
 cmnds.add('yahoo-image', handle_yahoo_image, 'USER')
 
+## yahoo-search command
+
 def handle_yahoo_search(bot, ievent):
     if ievent.inqueue:
         text = ' '.join(waitforqueue(ievent.inqueue, 5))
@@ -583,6 +596,8 @@ cmnds.add('yahoo-search', handle_yahoo_search, 'USER')
 aliases.data['y!'] = 'yahoo-search'
 aliases.data['yahoo'] = 'yahoo-search'
 
+## yahoo-pagedata command
+
 def handle_yahoo_pagedata(bot, ievent):
     if not ievent.args:
         ievent.missing('<url>')
@@ -603,6 +618,7 @@ def handle_yahoo_pagedata(bot, ievent):
 
 cmnds.add('yahoo-pagedata', handle_yahoo_pagedata, ['USER'])
 
+## yahoo-video command
 
 def handle_yahoo_video(bot, ievent):
     adult_ok = 0
@@ -644,3 +660,4 @@ def handle_yahoo_video(bot, ievent):
 
 cmnds.add('yahoo-video', handle_yahoo_video, 'USER')
 
+#### BHJTW 23-01-2012
